% Auto-generated chapter 24 for abudawud
% Hadiths in this chapter: 155

\hadithdefcmd{abudawud}{3416}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَحُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، عَنْ مُغِيرَةَ بْنِ زِيَادٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنِ الأَسْوَدِ بْنِ ثَعْلَبَةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ عَلَّمْتُ نَاسًا مِنْ أَهْلِ الصُّفَّةِ الْكِتَابَ وَالْقُرْآنَ فَأَهْدَى إِلَىَّ رَجُلٌ مِنْهُمْ قَوْسًا فَقُلْتُ لَيْسَتْ بِمَالٍ وَأَرْمِي عَنْهَا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ لآتِيَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَلأَسْأَلَنَّهُ فَأَتَيْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ رَجُلٌ أَهْدَى إِلَىَّ قَوْسًا مِمَّنْ كُنْتُ أُعَلِّمُهُ الْكِتَابَ وَالْقُرْآنَ وَلَيْسَتْ بِمَالٍ وَأَرْمِي عَنْهَا فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ ‏ "‏ إِنْ كُنْتَ تُحِبُّ أَنْ تُطَوَّقَ طَوْقًا مِنْ نَارٍ فَاقْبَلْهَا ‏"‏ ‏.‏\hadithno{3416}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubaydah ibn as-Samit: I taught some persons of the people of Suffah writing and the Qur'an. A man of them presented to me a bow. I said: It cannot be reckoned property; may I shoot with it in Allah's path? I must come to the Apostle of of Allah (ﷺ) and ask him (about it). So I came to him and said : Messenger of Allah (ﷺ), one of those whom I have been teaching writing and the Qur'an has presented me a bow, and as it cannot be reckoned property, may I shoot with it in Allah's path? He said: If you want to have a necklace of fire on you, accept it}}
\hadithdefcmd{abudawud}{3417}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، وَكَثِيرُ بْنُ عُبَيْدٍ، قَالاَ حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي بِشْرُ بْنُ عَبْدِ اللَّهِ بْنِ يَسَارٍ، قَالَ عَمْرٌو حَدَّثَنِي عُبَادَةُ بْنُ نُسَىٍّ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، نَحْوَ هَذَا الْخَبَرِ - وَالأَوَّلُ أَتَمُّ - فَقُلْتُ مَا تَرَى فِيهَا يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ جَمْرَةٌ بَيْنَ كَتِفَيْكَ تَقَلَّدْتَهَا ‏"‏ ‏.‏ أَوْ ‏"‏ تَعَلَّقْتَهَا ‏"‏ ‏.‏\hadithno{3417}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{A similar tradition has also been transmitted by 'Ubadah b. al-Samit through a different chain of narrators, but the former tradition is more perfect. This version has:I said: What do you think about it, Messenger of Allah? He said: A live coal between your shoulders which you have put around your neck or hanged it}}
\hadithdefcmd{abudawud}{3418}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَهْطًا، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم انْطَلَقُوا فِي سَفْرَةٍ سَافَرُوهَا فَنَزَلُوا بِحَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَاسْتَضَافُوهُمْ فَأَبَوْا أَنْ يُضَيِّفُوهُمْ - قَالَ - فَلُدِغَ سَيِّدُ ذَلِكَ الْحَىِّ فَشَفَوْا لَهُ بِكُلِّ شَىْءٍ لاَ يَنْفَعُهُ شَىْءٌ ‏.‏ فَقَالَ بَعْضُهُمْ لَوْ أَتَيْتُمْ هَؤُلاَءِ الرَّهْطَ الَّذِينَ نَزَلُوا بِكُمْ لَعَلَّ أَنْ يَكُونَ عِنْدَ بَعْضِهِمْ شَىْءٌ يَنْفَعُ صَاحِبَكُمْ فَقَالَ بَعْضُهُمْ إِنَّ سَيِّدَنَا لُدِغَ فَشَفَيْنَا لَهُ بِكُلِّ شَىْءٍ فَلاَ يَنْفَعُهُ شَىْءٌ فَهَلْ عِنْدَ أَحَدٍ مِنْكُمْ شَىْءٌ يَشْفِي صَاحِبَنَا يَعْنِي رُقْيَةً ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ إِنِّي لأَرْقِي وَلَكِنِ اسْتَضَفْنَاكُمْ فَأَبَيْتُمْ أَنْ تُضَيِّفُونَا مَا أَنَا بِرَاقٍ حَتَّى تَجْعَلُوا لِي جُعْلاً ‏.‏ فَجَعَلُوا لَهُ قَطِيعًا مِنَ الشَّاءِ فَأَتَاهُ فَقَرَأَ عَلَيْهِ بِأُمِّ الْكِتَابِ وَيَتْفُلُ حَتَّى بَرِئَ كَأَنَّمَا أُنْشِطَ مِنْ عِقَالٍ فَأَوْفَاهُمْ جُعْلَهُمُ الَّذِي صَالَحُوهُ عَلَيْهِ ‏.‏ فَقَالُوا اقْتَسِمُوا فَقَالَ الَّذِي رَقَى لاَ تَفْعَلُوا حَتَّى نَأْتِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَنَسْتَأْمِرَهُ ‏.‏ فَغَدَوْا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِنْ أَيْنَ عَلِمْتُمْ أَنَّهَا رُقْيَةٌ أَحْسَنْتُمْ وَاضْرِبُوا لِي مَعَكُمْ بِسَهْمٍ ‏"‏ ‏.‏\hadithno{3418}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari (2276) Sahih Muslim (2201)}\hadithtrans{Narrated Abu Sa’id Al Khudri :Some of the Companions of Prophet (ﷺ) went on a journey. They encamped with a clan of the Arabs and sought hospitality from them, but they refused to provide them with any hospitality. The chief of the clan was stung by a scorpion or bitten by a snake. They gave him all sorts of treatment, but nothing gave him relied. One of them said: Would that you had gone to those people who encamped with you ; some of them might have something which could give you relief to your companion. (So they went and) one of them said: Our chief has been stung by a scorpion or bitten by a snake. We administered all sorts of medicine but nothing gave him relief. Has any of you anything, i.e. charm, which gives healing to our companion. One of those people said: I shall apply charm; we sought hospitality from you, but you refused to entertain us. I am not going to apply charm until you give me some wages. So they offered them a number of sheep. He then came to and recited Faithat-al-Kitab and spat until he was cured as if he were set free from a bond. Thereafter they made payment of the wages as agreed by them. They said: Apportion (the wages). The man who applied the charm said: Do not do until we come to the Messenger of Allah (ﷺ) and consult him. So they came to the Messenger of Allah (ﷺ) next morning and mentioned it to him. The Messenger of Allah (ﷺ) said: From where did you learn that it was a charm ? You have done right. Give me a share along with you}}
\hadithdefcmd{abudawud}{3419}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَخِيهِ، مَعْبَدِ بْنِ سِيرِينَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{3419}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5007) Sahih Muslim (2201)}\hadithtrans{This tradition has also been transmitted by Abu Sa'id al-Khudri form the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3420}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ خَارِجَةَ بْنِ الصَّلْتِ، عَنْ عَمِّهِ، أَنَّهُ مَرَّ بِقَوْمٍ فَأَتَوْهُ فَقَالُوا إِنَّكَ جِئْتَ مِنْ عِنْدِ هَذَا الرَّجُلِ بِخَيْرٍ فَارْقِ لَنَا هَذَا الرَّجُلَ ‏.‏ فَأَتَوْهُ بِرَجُلٍ مَعْتُوهٍ فِي الْقُيُودِ فَرَقَاهُ بِأُمِّ الْقُرْآنِ ثَلاَثَةَ أَيَّامٍ غُدْوَةً وَعَشِيَّةً كُلَّمَا خَتَمَهَا جَمَعَ بُزَاقَهُ ثُمَّ تَفَلَ فَكَأَنَّمَا أُنْشِطَ مِنْ عِقَالٍ فَأَعْطُوهُ شَيْئًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَهُ لَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلْ فَلَعَمْرِي لَمَنْ أَكَلَ بِرُقْيَةٍ بَاطِلٍ لَقَدْ أَكَلْتَ بِرُقْيَةٍ حَقٍّ ‏"‏ ‏.‏\hadithno{3420}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Kharijah b. al-Salt quoted his paternal uncle as saying that he passed by a clan (of the Arab) who came to him and said:You have brought what is good from this man. Then they brought a lunatic in chains. He recited Surat al-Fatihah over him three days, morning and evening. When he finished, he collected his saliva and then spat it out, (he felt relief) as if he were set free from a bond. They gave him something (as wages). He then came to the Prophet (ﷺ) and mentioned it to him. The Messenger of Allah (ﷺ) said: Accept it, for by my life, some accept it for a worthless charm, but you have done so far a genuine one}}
\hadithdefcmd{abudawud}{3421}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا أَبَانُ، عَنْ يَحْيَى، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ قَارِظٍ - عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَسْبُ الْحَجَّامِ خَبِيثٌ وَثَمَنُ الْكَلْبِ خَبِيثٌ وَمَهْرُ الْبَغِيِّ خَبِيثٌ ‏"‏ ‏.‏\hadithno{3421}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1568)}\hadithtrans{Narrated Rafi' ibn Khadij: The Prophet (ﷺ) said: The earnings of a cupper are impure, the price paid for a dog is impure, and the hire paid to a prostitute is impure}}
\hadithdefcmd{abudawud}{3422}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ مُحَيِّصَةَ، عَنْ أَبِيهِ، أَنَّهُ اسْتَأْذَنَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي إِجَارَةِ الْحَجَّامِ فَنَهَاهُ عَنْهَا فَلَمْ يَزَلْ يَسْأَلُهُ وَيَسْتَأْذِنُهُ حَتَّى أَمَرَهُ أَنِ اعْلِفْهُ نَاضِحَكَ وَرَقِيقَكَ ‏.‏\hadithno{3422}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Muhayyisah ibn Ka'b: Muhayyisah asked permission of the Messenger of Allah (ﷺ) regarding hire of the cupper, but he forbade him. He kept on asking his permission, and at last he said to him: Feed your watering camel with it and feed your slave with it}}
\hadithdefcmd{abudawud}{3423}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَعْطَى الْحَجَّامَ أَجْرَهُ وَلَوْ عَلِمَهُ خَبِيثًا لَمْ يُعْطِهِ ‏.‏\hadithno{3423}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2279)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) got him self cupped and gave the cupper his wages. Had he considered it impure, he would not have given it (wage) to him}}
\hadithdefcmd{abudawud}{3424}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ حَجَمَ أَبُو طَيْبَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَمَرَ لَهُ بِصَاعٍ مِنْ تَمْرٍ وَأَمَرَ أَهْلَهُ أَنْ يُخَفِّفُوا عَنْهُ مِنْ خَرَاجِهِ ‏.‏\hadithno{3424}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2102) Sahih Muslim (1577)}\hadithtrans{Narrated Anas b. Malik :That Abu Tibah cupped the Messenger of Allah (ﷺ) and he ordered that a sa' of dates be given to him, also ordering his people to remit some of his dues}}
\hadithdefcmd{abudawud}{3425}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، قَالَ سَمِعْتُ أَبَا حَازِمٍ، سَمِعَ أَبَا هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كَسْبِ الإِمَاءِ ‏.‏\hadithno{3425}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2283)}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) forbade earnings of slave-girls}}
\hadithdefcmd{abudawud}{3426}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا عِكْرِمَةُ، حَدَّثَنِي طَارِقُ بْنُ عَبْدِ الرَّحْمَنِ الْقُرَشِيُّ، قَالَ جَاءَ رَافِعُ بْنُ رِفَاعَةَ إِلَى مَجْلِسِ الأَنْصَارِ فَقَالَ لَقَدْ نَهَانَا نَبِيُّ اللَّهِ صلى الله عليه وسلم الْيَوْمَ فَذَكَرَ أَشْيَاءَ وَنَهَانَا عَنْ كَسْبِ الأَمَةِ إِلاَّ مَا عَمِلَتْ بِيَدِهَا ‏.‏ وَقَالَ هَكَذَا بِأَصَابِعِهِ نَحْوَ الْخَبْزِ وَالْغَزْلِ وَالنَّفْشِ ‏.‏\hadithno{3426}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Tariq ibn AbdurRahman al-Qarash: Rafi' ibn Rifa'ah came to a meeting of the Ansar and said: The Prophet of Allah (ﷺ) forbade us (from some things) today, and he mentioned some things. He forbade the earning of a slave-girl except what she earned with her hand. He indicated (some things) with his fingers such as baking, spinning, and ginning}}
\hadithdefcmd{abudawud}{3427}{حَدَّثَنِي أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عُبَيْدِ اللَّهِ، - يَعْنِي ابْنَ هُرَيْرٍ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، رَافِعٍ - هُوَ ابْنُ خَدِيجٍ - قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كَسْبِ الأَمَةِ حَتَّى يُعْلَمَ مِنْ أَيْنَ هُوَ ‏.‏\hadithno{3427}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Rafi' b. Khadij:The Messenger of Allah (ﷺ) forbade earnings of a slave-girl unless it is known from where it came}}
\hadithdefcmd{abudawud}{3428}{حَدَّثَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏\hadithno{3428}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5761) Sahih Muslim (1567)}\hadithtrans{Narrated AbuMas'ud: The Prophet (ﷺ) forbade the price paid for a dog, the hire paid to a prostitute, and the gift given to a soothsayer}}
\hadithdefcmd{abudawud}{3429}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَسْبِ الْفَحْلِ ‏.‏\hadithno{3429}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2284)}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) forbade (taking hire for) a stallion's covering}}
\hadithdefcmd{abudawud}{3430}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَاجِدَةَ، قَالَ قَطَعْتُ مِنْ أُذُنِ غُلاَمٍ - أَوْ قُطِعَ مِنْ أُذُنِي - فَقَدِمَ عَلَيْنَا أَبُو بَكْرٍ حَاجًّا فَاجْتَمَعْنَا إِلَيْهِ فَرَفَعَنَا إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ عُمَرُ إِنَّ هَذَا قَدْ بَلَغَ الْقِصَاصَ ادْعُوا لِي حَجَّامًا لِيَقْتَصَّ مِنْهُ فَلَمَّا دُعِيَ الْحَجَّامُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنِّي وَهَبْتُ لِخَالَتِي غُلاَمًا وَأَنَا أَرْجُو أَنْ يُبَارَكَ لَهَا فِيهِ فَقُلْتُ لَهَا لاَ تُسَلِّمِيهِ حَجَّامًا وَلاَ صَائِغًا وَلاَ قَصَّابًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى عَبْدُ الأَعْلَى عَنِ ابْنِ إِسْحَاقَ قَالَ ابْنُ مَاجِدَةَ رَجُلٌ مِنْ بَنِي سَهْمٍ عَنْ عُمَرَ بْنِ الْخَطَّابِ ‏.‏\hadithno{3430}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{AbuMajidah said:I cut the ear of a boy, or he cut my ear (the narrator is doubtful). AbuBakr then came to us to perform hajj and we got together with him. But he referred us to Umar ibn al-Khattab. Umar (ibn al-Khattab) said: This reached the extent of retaliation. Call a cupper to me so that he may retaliate. When the cupper was called, he (Umar) said: I heard the Messenger of Allah (ﷺ) say: I gave a boy to my maternal aunt, and I hope that she will be blessed in respect of him. I said to her: Do not entrust him to a supper, nor to a goldsmith, nor to a butcher. Abu Dawud said: This tradition has also been transmitted by 'Abd al-A'la from Ibn Ishaq who said: Abu Majidah is a man of Banu Sahm narrating from 'Umar b. al-Khattab}}
\hadithdefcmd{abudawud}{3431}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا سَلَمَةُ بْنُ الْفَضْلِ، حَدَّثَنَا ابْنُ إِسْحَاقَ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ الْحُرَقِيُّ، عَنِ ابْنِ مَاجِدَةَ السَّهْمِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3431}\hadithgrade{Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Abu Majidah al-Sahmi from 'Umar b. al-Khattab through a different chain of narrators}}
\hadithdefcmd{abudawud}{3432}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنَا الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ الْحُرَقِيُّ، عَنِ ابْنِ مَاجِدَةَ السَّهْمِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3432}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Majidah quoted 'Umar b. al-Khattab as saying:I heard the Prophet (ﷺ) say ... narrating the tradition to the same effect}}
\hadithdefcmd{abudawud}{3433}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَهُ الْمُبْتَاعُ وَمَنْ بَاعَ نَخْلاً مُؤَبَّرًا فَالثَّمَرَةُ لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{3433}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2379) Sahih Muslim (1543)}\hadithtrans{Narrated Ibn 'Umar:The Prophet (ﷺ) as saying: If anyone buys a slave who possesses property. his property belongs to the seller unless buyer makes a provision and if anyone buys palm-trees after they have been fecundated, the fruit belongs to the seller unless the buyer make a provision}}
\hadithdefcmd{abudawud}{3434}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِقِصَّةِ الْعَبْدِ وَعَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِقِصَّةِ النَّخْلِ ‏.‏ قَالَ أَبُو دَاوُدَ وَاخْتَلَفَ الزُّهْرِيُّ وَنَافِعٌ فِي أَرْبَعَةِ أَحَادِيثَ هَذَا أَحَدُهَا ‏.‏\hadithno{3434}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2379) Sahih Muslim (1543)}\hadithtrans{This tradition has also been narrated by 'Umar from the Messenger of Allah (ﷺ) through a different chain of narrators. It mentions only the sale of the slave. It has also been transmitted by Nafi' on the authority of Ibn 'Umar from the Prophet (ﷺ) indicating only the sale of palm-trees. Abu Dawud said:Al-Zuhri and Nafi' differed among themselves in four traditions. This is one of them}}
\hadithdefcmd{abudawud}{3435}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي سَلَمَةُ بْنُ كُهَيْلٍ، حَدَّثَنِي مَنْ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{3435}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If anyone buys a slave who possesses property, his property belongs to the seller unless the buyer makes a proviso}}
\hadithdefcmd{abudawud}{3436}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ تَلَقَّوُا السِّلَعَ حَتَّى يُهْبَطَ بِهَا الأَسْوَاقَ ‏"‏ ‏.‏\hadithno{3436}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2139، 2165) Sahih Muslim (1412 After  1514)}\hadithtrans{Narrated 'Abdullah bin 'Umar:The Messenger of Allah (ﷺ) as saying: None of you must buy in opposition to one another ; and do not go out to meet the merchandise, (but one must wait) till it is brought down to the market}}
\hadithdefcmd{abudawud}{3437}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ عَمْرٍو الرَّقِّيَّ - عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ تَلَقِّي الْجَلَبِ فَإِنْ تَلَقَّاهُ مُتَلَقٍّ مُشْتَرٍ فَاشْتَرَاهُ فَصَاحِبُ السِّلْعَةِ بِالْخِيَارِ إِذَا وَرَدَتِ السُّوقَ ‏.‏ قَالَ أَبُو عَلِيٍّ سَمِعْتُ أَبَا دَاوُدَ يَقُولُ قَالَ سُفْيَانُ لاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ أَنْ يَقُولَ إِنَّ عِنْدِي خَيْرًا مِنْهُ بِعَشْرَةٍ ‏.‏\hadithno{3437}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:Do not go our to meet what is being brought (to market for sale). If anyone does so and buys some of it, the owner of merchandise has a choice (of canceling the deal) when it comes to the market. Abu 'Ali said: I heard Abu Dawud say: Sufyan said: none of you must buy in opposition to one another ; that is he says: I have a better one for ten (dirhams)}}
\hadithdefcmd{abudawud}{3438}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَنَاجَشُوا ‏"‏ ‏.‏\hadithno{3438}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2140) Sahih Muslim (1413)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) forbade to bid against one another}}
\hadithdefcmd{abudawud}{3439}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏ فَقُلْتُ مَا يَبِيعُ حَاضِرٌ لِبَادٍ قَالَ لاَ يَكُونُ لَهُ سِمْسَارًا ‏.‏\hadithno{3439}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2158) Sahih Muslim (1521)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) forbade a townsman to sell for a man from the desert. I asked: What do you mean by the selling of a townsman for a man from the desert ? He replied: He should not be a broker for him}}
\hadithdefcmd{abudawud}{3440}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، أَنَّ مُحَمَّدَ بْنَ الزِّبْرِقَانَ أَبَا هَمَّامٍ، حَدَّثَهُمْ - قَالَ زُهَيْرٌ وَكَانَ ثِقَةً - عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ وَإِنْ كَانَ أَخَاهُ أَوْ أَبَاهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ حَفْصَ بْنَ عُمَرَ يَقُولُ حَدَّثَنَا أَبُو هِلاَلٍ حَدَّثَنَا مُحَمَّدٌ عَنْ أَنَسِ بْنِ مَالِكٍ قَالَ كَانَ يُقَالُ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ ‏.‏ وَهِيَ كَلِمَةٌ جَامِعَةٌ لاَ يَبِيعُ لَهُ شَيْئًا وَلاَ يَبْتَاعُ لَهُ شَيْئًا ‏.‏\hadithno{3440}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: A townsman must not sell for a man from the desert, even if he is his brother or father. Abu Dawud said: Anas b. Malik said: It was said: A townsman must not sell for a man from the desert. This phrase carries a broad meaning. It means that the (the townsman) must not sell anything for him or buy anything for him}}
\hadithdefcmd{abudawud}{3441}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَالِمٍ الْمَكِّيِّ، أَنَّ أَعْرَابِيًّا، حَدَّثَهُ أَنَّهُ، قَدِمَ بِحَلُوبَةٍ لَهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَزَلَ عَلَى طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ وَلَكِنِ اذْهَبْ إِلَى السُّوقِ فَانْظُرْ مَنْ يُبَايِعُكَ فَشَاوِرْنِي حَتَّى آمُرَكَ أَوْ أَنْهَاكَ ‏.‏\hadithno{3441}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salim al-Makki: That a bedouin told him that he brought a milch she-camel in the time of the Messenger of Allah (ﷺ). He alighted with Talhah ibn Ubaydullah (and wanted to sell his milch animal to him). He said: The Prophet (ﷺ) forbade a townsman to sell for a man from the desert. But go to the market and see who buys from you. consult me thereafter, and then I shall ask you (to sell) or forbid you}}
\hadithdefcmd{abudawud}{3442}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبِعْ حَاضِرٌ لِبَادٍ وَذَرُوا النَّاسَ يَرْزُقِ اللَّهُ بَعْضَهُمْ مِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{3442}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1522)}\hadithtrans{Narrated Jabir: The Messenger of Allah (ﷺ) as saying: A townsman must not sell for a man from the desert ; and leave people alone, Allah will give them provision from one another}}
\hadithdefcmd{abudawud}{3443}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَلَقَّوُا الرُّكْبَانَ لِلْبَيْعِ وَلاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ تُصَرُّوا الإِبِلَ وَالْغَنَمَ فَمَنِ ابْتَاعَهَا بَعْدَ ذَلِكَ فَهُوَ بِخَيْرِ النَّظَرَيْنِ بَعْدَ أَنْ يَحْلِبَهَا فَإِنْ رَضِيَهَا أَمْسَكَهَا وَإِنْ سَخِطَهَا رَدَّهَا وَصَاعًا مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{3443}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2150) Sahih Muslim (1515)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Do not go out to meet riders to conduct business with them ; none of you must buy in opposition to one another; and do not tie up the udders of camels and sheep, for he who buys them after that has been done has two courses open to him after milking them: he may keep them if he is pleased with them, or he may return them along with a sa' of dates is he is displeased with them}}
\hadithdefcmd{abudawud}{3444}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَهِشَامٍ، وَحَبِيبٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اشْتَرَى شَاةً مُصَرَّاةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ إِنْ شَاءَ رَدَّهَا وَصَاعًا مِنْ طَعَامٍ لاَ سَمْرَاءَ ‏"‏ ‏.‏\hadithno{3444}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1524)}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) as saying: If anyone buys sheep whose udders have been tied up, he has option for three days: he may return it if he desires with a sa' of any grain, not (necessarily) wheat}}
\hadithdefcmd{abudawud}{3445}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَخْلَدٍ التَّمِيمِيُّ، حَدَّثَنَا الْمَكِّيُّ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي زِيَادٌ، أَنَّ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اشْتَرَى غَنَمًا مُصَرَّاةً احْتَلَبَهَا فَإِنْ رَضِيَهَا أَمْسَكَهَا وَإِنْ سَخِطَهَا فَفِي حَلْبَتِهَا صَاعٌ مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{3445}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2151)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: If anyone buys sheep or goat whose udders have been tied up and he milked it, he may keep it if he is pleased with it, or he may return it if he is displeased with it. There is one sa' of dates (which he must give to the seller) for milking it}}
\hadithdefcmd{abudawud}{3446}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا صَدَقَةُ بْنُ سَعِيدٍ، عَنْ جُمَيْعِ بْنِ عُمَيْرٍ التَّيْمِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ مُحَفَّلَةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ فَإِنْ رَدَّهَا رَدَّ مَعَهَا مِثْلَ أَوْ مِثْلَىْ لَبَنِهَا قَمْحًا ‏"‏ ‏.‏\hadithno{3446}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: If anyone buys a sheep whose udders have been tied up, he has option for three days (for decision). If he returns it, he should return with it wheat equal to its milk or double of it}}
\hadithdefcmd{abudawud}{3447}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ مَعْمَرِ بْنِ أَبِي مَعْمَرٍ، أَحَدِ بَنِي عَدِيِّ بْنِ كَعْبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحْتَكِرُ إِلاَّ خَاطِئٌ ‏"‏ ‏.‏ فَقُلْتُ لِسَعِيدٍ فَإِنَّكَ تَحْتَكِرُ قَالَ وَمَعْمَرٌ كَانَ يَحْتَكِرُ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَأَلْتُ أَحْمَدَ مَا الْحُكْرَةُ قَالَ مَا فِيهِ عَيْشُ النَّاسِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ الأَوْزَاعِيُّ الْمُحْتَكِرُ مَنْ يَعْتَرِضُ السُّوقَ ‏.‏\hadithno{3447}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1605)}\hadithtrans{Narrated Ma'mar b. Abi Ma'mar, one of the children of 'Adi b. Ka'b: The Messenger of Allah (ﷺ) as saying: No one withholds goods till their price rises but a sinner. I said to Sa'id (b. al-Musayyab): You withhold goods till their price rises. He said: Ma'mar used to withhold goods till their price rose. Abu Dawud said: I asked Ahmad (b. Hanbal): What is hoarding (hukrah) ? He replied: That on which people live. Abu Dawud said: Al-Auza'i said: A muhtakir (one who hoards) is one who withholds supply of goods in the market}}
\hadithdefcmd{abudawud}{3448}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَيَّاضٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ الْفَيَّاضِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ لَيْسَ فِي التَّمْرِ حُكْرَةٌ ‏.‏ قَالَ ابْنُ الْمُثَنَّى قَالَ عَنِ الْحَسَنِ فَقُلْنَا لَهُ لاَ تَقُلْ عَنِ الْحَسَنِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ عِنْدَنَا بَاطِلٌ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ سَعِيدُ بْنُ الْمُسَيَّبِ يَحْتَكِرُ النَّوَى وَالْخَبَطَ وَالْبِزْرَ سَمِعْتُ أَحْمَدَ بْنَ يُونُسَ يَقُولُ سَأَلْتُ سُفْيَانَ عَنْ كَبْسِ الْقَتِّ فَقَالَ كَانُوا يَكْرَهُونَ الْحُكْرَةَ وَسَأَلْتُ أَبَا بَكْرِ بْنَ عَيَّاشٍ فَقَالَ اكْبِسْهُ ‏.‏\hadithno{3448}\hadithgrade{Al-Albani: Daif Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad Maqtu; Shuaib Al Arnaut: Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Qatadah said:Hoarding does not apply to dried dates. Ibn al-Muthanna said that he (Yahya b. Fayyad) reported on the authority of al-Hasan. We (Ibn al-Muthanna) said to him (Yahya): Do not say: "on the authority of al-Hasan." Abu Dawud said: This tradition according to us is false. Abu Dawud said: Sa'id b. al-Musayyab used to hoard kernel, fodder, and seeds. Abu Dawud said: I heard Ahmad b. Yunus say: I asked Sufyan about hoarding fodder. He replied: They (the people in the past) disapproved of hoarding. I asked Abu Bakr b. 'Ayyash (about it). He replied: Hoard it}}
\hadithdefcmd{abudawud}{3449}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ مُحَمَّدَ بْنَ فَضَاءٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ عَلْقَمَةَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُكْسَرَ سِكَّةُ الْمُسْلِمِينَ الْجَائِزَةُ بَيْنَهُمْ إِلاَّ مِنْ بَأْسٍ ‏.‏\hadithno{3449}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Alqamah b. 'Abdullah: On the authority of his father, who said: The Messenger of Allah (ﷺ) forbade to break the coins of the Muslims current among them except for some defect}}
\hadithdefcmd{abudawud}{3450}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، أَنَّ سُلَيْمَانَ بْنَ بِلاَلٍ، حَدَّثَهُمْ حَدَّثَنِي الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، جَاءَ فَقَالَ يَا رَسُولَ اللَّهِ سَعِّرْ ‏.‏ فَقَالَ ‏"‏ بَلْ أَدْعُو ‏"‏ ‏.‏ ثُمَّ جَاءَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ سَعِّرْ فَقَالَ ‏"‏ بَلِ اللَّهُ يَخْفِضُ وَيَرْفَعُ وَإِنِّي لأَرْجُو أَنْ أَلْقَى اللَّهَ وَلَيْسَ لأَحَدٍ عِنْدِي مَظْلَمَةٌ ‏"‏ ‏.‏\hadithno{3450}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: A man came and said: Messenger of Allah, fix prices. He said: (No), but I shall pray. Again the man came and said: Messenger of Allah, fix prices. He said: It is but Allah Who makes the prices low and high. I hope that when I meet Allah, none of you has any claim on me for doing wrong regarding blood or property}}
\hadithdefcmd{abudawud}{3451}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، وَقَتَادَةُ، وَحُمَيْدٌ، عَنْ أَنَسٍ، قَالَ قَالَ النَّاسُ يَا رَسُولَ اللَّهِ غَلاَ السِّعْرُ فَسَعِّرْ لَنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ هُوَ الْمُسَعِّرُ الْقَابِضُ الْبَاسِطُ الرَّازِقُ وَإِنِّي لأَرْجُو أَنْ أَلْقَى اللَّهَ وَلَيْسَ أَحَدٌ مِنْكُمْ يُطَالِبُنِي بِمَظْلَمَةٍ فِي دَمٍ وَلاَ مَالٍ ‏"‏ ‏.‏\hadithno{3451}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The people said: Messenger of Allah , prices have shot up, so fix prices for us. Thereupon the Messenger of Allah (ﷺ) said: Allah is the one Who fixes prices, Who withholds, gives lavishly and provides, and I hope that when I meet Allah, none of you will have any claim on me for an injustice regarding blood or property}}
\hadithdefcmd{abudawud}{3452}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِرَجُلٍ يَبِيعُ طَعَامًا فَسَأَلَهُ ‏"‏ كَيْفَ تَبِيعُ ‏"‏ ‏.‏ فَأَخْبَرَهُ فَأُوحِيَ إِلَيْهِ أَنْ أَدْخِلْ يَدَكَ فِيهِ فَأَدْخَلَ يَدَهُ فِيهِ فَإِذَا هُوَ مَبْلُولٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَّا مَنْ غَشَّ ‏"‏ ‏.‏\hadithno{3452}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) passed a man who was selling grain. He asked him: How are you selling? He informed him. Revelation them came down to him saying: "Put your hand into it." So he put his hand into it, and felt that it was damp. The Messenger of Allah (ﷺ) then said: "He who deceives has nothing to do with us}}
\hadithdefcmd{abudawud}{3453}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، عَنْ عَلِيٍّ، عَنْ يَحْيَى، قَالَ كَانَ سُفْيَانُ يَكْرَهُ هَذَا التَّفْسِيرَ لَيْسَ مِنَّا لَيْسَ مِثْلَنَا ‏.‏\hadithno{3453}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yahya said:Sufyan disapproved of the interpretation of the phrase "has nothing to do with us" as "not like us}}
\hadithdefcmd{abudawud}{3454}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُتَبَايِعَانِ كُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ عَلَى صَاحِبِهِ مَا لَمْ يَفْتَرِقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{3454}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2111) Sahih Muslim (1531)}\hadithtrans{Narrated 'Abdullah bin 'Umar:The Messenger of Allah (ﷺ) as saying: Each one of the two parties in a business has an option (to annul it) against the other party so long as they have not separated, except in a conditional bargain}}
\hadithdefcmd{abudawud}{3455}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ ‏ "‏ أَوْ يَقُولُ أَحَدُهُمَا لِصَاحِبِهِ اخْتَرْ ‏"‏ ‏.‏\hadithno{3455}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2109) Sahih Muslim (1531)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar from the Prophet (ﷺ) to the same effect through a different chain of narrators. This version adds:"Or one of them tells the other: "Exercise the right}}
\hadithdefcmd{abudawud}{3456}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُتَبَايِعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا إِلاَّ أَنْ تَكُونَ صَفْقَةَ خِيَارٍ وَلاَ يَحِلُّ لَهُ أَنْ يُفَارِقَ صَاحِبَهُ خَشْيَةَ أَنْ يَسْتَقِيلَهُ ‏"‏ ‏.‏\hadithno{3456}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Both parties in a business transaction have a right to annul it so long as they have not separated unless it is a bargain with the option to annul is attached to it; and it is not permissible for one of them to separate from the other for fear that one may demand that the bargain be rescinded}}
\hadithdefcmd{abudawud}{3457}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ جَمِيلِ بْنِ مُرَّةَ، عَنْ أَبِي الْوَضِيءِ، قَالَ غَزَوْنَا غَزْوَةً لَنَا فَنَزَلْنَا مَنْزِلاً فَبَاعَ صَاحِبٌ لَنَا فَرَسًا بِغُلاَمٍ ثُمَّ أَقَامَا بَقِيَّةَ يَوْمِهِمَا وَلَيْلَتِهِمَا فَلَمَّا أَصْبَحَا مِنَ الْغَدِ حَضَرَ الرَّحِيلُ فَقَامَ إِلَى فَرَسِهِ يُسْرِجُهُ فَنَدِمَ فَأَتَى الرَّجُلَ وَأَخَذَهُ بِالْبَيْعِ فَأَبَى الرَّجُلُ أَنْ يَدْفَعَهُ إِلَيْهِ فَقَالَ بَيْنِي وَبَيْنَكَ أَبُو بَرْزَةَ صَاحِبُ النَّبِيِّ صلى الله عليه وسلم فَأَتَيَا أَبَا بَرْزَةَ فِي نَاحِيَةِ الْعَسْكَرِ فَقَالاَ لَهُ هَذِهِ الْقِصَّةَ ‏.‏ فَقَالَ أَتَرْضَيَانِ أَنْ أَقْضِيَ بَيْنَكُمَا بِقَضَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ‏"‏ ‏.‏ قَالَ هِشَامُ بْنُ حَسَّانَ حَدَّثَ جَمِيلٌ أَنَّهُ قَالَ مَا أُرَاكُمَا افْتَرَقْتُمَا ‏.‏\hadithno{3457}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbulWadi': We fought one of our battle, and encamped at a certain place. One of our companions sold a horse for a slave. After that they remained there for the rest of day and night. When the next morning came, they prepared themselves for departure. The buyer of the horse began to saddle it, but the seller was ashamed (of the transaction). He went to the man (buyer) and asked him to annul the transaction. The man refused to hand it over (the horse) to him. He said: AbuBarzah, the companion of the Prophet (ﷺ), is to decide between me and you. They went to AbuBarzah in the corner of the army. They related this story to him. He said: Do you agree that I make a decision between you on the basis of the decision of the Messenger of Allah (ﷺ)? The Messenger of Allah (ﷺ) said: Both parties in a business transaction have an option (right) to annul it so long as they have not separated. Hisham to Hassan said that Jamil said in his version: "I do not think that you separated}}
\hadithdefcmd{abudawud}{3458}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْجَرْجَرَائِيُّ، قَالَ مَرْوَانُ الْفَزَارِيُّ أَخْبَرَنَا عَنْ يَحْيَى بْنِ أَيُّوبَ، قَالَ كَانَ أَبُو زُرْعَةَ إِذَا بَايَعَ رَجُلاً خَيَّرَهُ قَالَ ثُمَّ يَقُولُ خَيِّرْنِي وَيَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَفْتَرِقَنَّ اثْنَانِ إِلاَّ عَنْ تَرَاضٍ ‏"‏ ‏.‏\hadithno{3458}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Yahya b. Ayyub: When Abu Zur'ah made a business transaction with a man, he gave him the right of option. He then would tell him: Give me the right of option (to annul the bargain). He said: I heard AbuHurayrah say: The Messenger of Allah (ﷺ) said: Two people must separate only by mutual consent}}
\hadithdefcmd{abudawud}{3459}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا وَإِنْ كَتَمَا وَكَذَبَا مُحِقَتِ الْبَرَكَةُ مِنْ بَيْعِهِمَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ سَعِيدُ بْنُ أَبِي عَرُوبَةَ وَحَمَّادٌ وَأَمَّا هَمَّامٌ فَقَالَ ‏"‏ حَتَّى يَتَفَرَّقَا أَوْ يَخْتَارَ ‏"‏ ‏.‏ ثَلاَثَ مِرَارٍ ‏.‏\hadithno{3459}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2079) Sahih Muslim (1532)}\hadithtrans{Narrated Hakim b. Hizam: The Messenger of Allah (ﷺ) as saying: Both parties in a business transaction have a right of option (to annul it) so long as they are not separated ; and if they tell the truth and make everything clear, they will be blessed in their transaction, but it they conceal anything and lie, the blessing on their transaction will be blotted out. Abu Dawud said: A similar tradition has also been transmitted by Sa'id b. Abi 'Arubah and Hammad. As regards with Hammam, he said in his version: Until they separate or exercise the right of option (to annul the transaction), saying the words of option three times}}
\hadithdefcmd{abudawud}{3460}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَفْصٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَقَالَ مُسْلِمًا أَقَالَهُ اللَّهُ عَثْرَتَهُ ‏"‏ ‏.‏\hadithno{3460}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone rescinds a sale with a Muslim, Allah will cancel his slip, on the Day of Resurrection}}
\hadithdefcmd{abudawud}{3461}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، عَنْ يَحْيَى بْنِ زَكَرِيَّا، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ بَاعَ بَيْعَتَيْنِ فِي بَيْعَةٍ فَلَهُ أَوْكَسُهُمَا أَوِ الرِّبَا ‏"‏ ‏.‏\hadithno{3461}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone makes two transactions combined in one bargain, he should have the lesser of the two or it will involve usury}}
\hadithdefcmd{abudawud}{3462}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ بْنُ شُرَيْحٍ، ح وَحَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى الْبُرُلُّسِيُّ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، عَنْ إِسْحَاقَ أَبِي عَبْدِ الرَّحْمَنِ، - قَالَ سُلَيْمَانُ عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْخُرَاسَانِيِّ، - أَنَّ عَطَاءً الْخُرَاسَانِيَّ، حَدَّثَهُ أَنَّ نَافِعًا حَدَّثَهُ عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا تَبَايَعْتُمْ بِالْعِينَةِ وَأَخَذْتُمْ أَذْنَابَ الْبَقَرِ وَرَضِيتُمْ بِالزَّرْعِ وَتَرَكْتُمُ الْجِهَادَ سَلَّطَ اللَّهُ عَلَيْكُمْ ذُلاًّ لاَ يَنْزِعُهُ حَتَّى تَرْجِعُوا إِلَى دِينِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الإِخْبَارُ لِجَعْفَرٍ وَهَذَا لَفْظُهُ ‏.‏\hadithno{3462}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: I heard the Messenger of Allah, (ﷺ) say: When you enter into the inah transaction, hold the tails of oxen, are pleased with agriculture, and give up conducting jihad (struggle in the way of Allah). Allah will make disgrace prevail over you, and will not withdraw it until you return to your original religion}}
\hadithdefcmd{abudawud}{3463}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُمْ يُسْلِفُونَ فِي التَّمْرِ السَّنَةَ وَالسَّنَتَيْنِ وَالثَّلاَثَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَسْلَفَ فِي تَمْرٍ فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏ ‏.‏\hadithno{3463}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2240) Sahih Muslim (1604)}\hadithtrans{Narrated Ibn 'Abbas:When the Messenger of Allah (ﷺ) came to Medina, they were paying one, two and three years in advance for fruits, so he said: Those who pay in advance for anything, must do for a specified measure and weight with a specified time fixed}}
\hadithdefcmd{abudawud}{3464}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا ابْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنِي مُحَمَّدٌ، أَوْ عَبْدُ اللَّهِ بْنُ مُجَالِدٍ قَالَ اخْتَلَفَ عَبْدُ اللَّهِ بْنُ شَدَّادٍ وَأَبُو بُرْدَةَ فِي السَّلَفِ فَبَعَثُونِي إِلَى ابْنِ أَبِي أَوْفَى فَسَأَلْتُهُ فَقَالَ إِنْ كُنَّا نُسْلِفُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ فِي الْحِنْطَةِ وَالشَّعِيرِ وَالتَّمْرِ وَالزَّبِيبِ - زَادَ ابْنُ كَثِيرٍ - إِلَى قَوْمٍ مَا هُوَ عِنْدَهُمْ ‏.‏ ثُمَّ اتَّفَقَا وَسَأَلْتُ ابْنَ أَبْزَى فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{3464}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2243)}\hadithtrans{Muhammad or 'Abd Allah b. Mujahid said:'Abd Allah b. Shaddad and Abu Burdah disputed over salaf (payment in advance). They sent me to Ibn Abi Awfa and I asked him (about it) and he replied: We used to pay in advance (salaf) during the time of the Messenger of Allah (ﷺ), Abu Bakr and 'Umar in wheat, barley, dates and raisins. Ibn Kathir added: "to those people who did not possess these things." The agreed version then goes: I then asked Ibn Abza who gave a similar reply}}
\hadithdefcmd{abudawud}{3465}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، وَابْنُ، مَهْدِيٍّ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْمُجَالِدِ، وَقَالَ عَبْدُ الرَّحْمَنِ، عَنِ ابْنِ أَبِي الْمُجَالِدِ، بِهَذَا الْحَدِيثِ قَالَ عِنْدَ قَوْمٍ مَا هُوَ عِنْدَهُمْ ‏.‏ قَالَ أَبُو دَاوُدَ الصَّوَابُ ابْنُ أَبِي الْمُجَالِدِ وَشُعْبَةُ أَخْطَأَ فِيهِ ‏.‏\hadithno{3465}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn Abi al-Mujahid through a different chain of narrators. This version has:"to those people who did not possess these things." Abu Dawud said: What is correct is Ibn Abi al-Mujahid. Shu'bah made a mistake in it}}
\hadithdefcmd{abudawud}{3466}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي غَنِيَّةَ، حَدَّثَنِي أَبُو إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى الأَسْلَمِيِّ، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الشَّامَ فَكَانَ يَأْتِينَا أَنْبَاطٌ مِنْ أَنْبَاطِ الشَّامِ فَنُسْلِفُهُمْ فِي الْبُرِّ وَالزَّيْتِ سِعْرًا مَعْلُومًا وَأَجَلاً مَعْلُومًا فَقِيلَ لَهُ مِمَّنْ لَهُ ذَلِكَ قَالَ مَا كُنَّا نَسْأَلُهُمْ ‏.‏\hadithno{3466}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn AbuAwfa ibn AbuAwfa al-Aslami: We made a journey to Syria on an expedition along with the Messenger of Allah (ﷺ). The Nabateans of Syria came to us and we paid in advance to them (in a salam contract) in wheat and olive oil at a specified rate and for a specified time. He asked (by the people): you might have contracted with him who had these things in his possession? He replied: We did not ask them}}
\hadithdefcmd{abudawud}{3467}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ رَجُلٍ، نَجْرَانِيٍّ عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، أَسْلَفَ رَجُلاً فِي نَخْلٍ فَلَمْ تُخْرِجْ تِلْكَ السَّنَةَ شَيْئًا فَاخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ بِمَ تَسْتَحِلُّ مَالَهُ ارْدُدْ عَلَيْهِ مَالَهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ لاَ تُسْلِفُوا فِي النَّخْلِ حَتَّى يَبْدُوَ صَلاَحُهُ ‏"‏ ‏.‏\hadithno{3467}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: A man paid in advance for a palm-tree. It did not bear fruit that year. They brought their case for decision to the Prophet (ﷺ). He said: for which do you make his property lawful? He then said: Do not pay in advance for a palm-tree till they (the fruits) were clearly in good condition}}
\hadithdefcmd{abudawud}{3468}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَبُو بَدْرٍ، عَنْ زِيَادِ بْنِ خَيْثَمَةَ، عَنْ سَعْدٍ، - يَعْنِي الطَّائِيَّ - عَنْ عَطِيَّةَ بْنِ سَعْدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَسْلَفَ فِي شَىْءٍ فَلاَ يَصْرِفْهُ إِلَى غَيْرِهِ ‏"‏ ‏.‏\hadithno{3468}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: If anyone pays in advance he must not transfer it to someone else before he receives it}}
\hadithdefcmd{abudawud}{3469}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ قَالَ أُصِيبَ رَجُلٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثِمَارٍ ابْتَاعَهَا فَكَثُرَ دَيْنُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا عَلَيْهِ ‏"‏ ‏.‏ فَتَصَدَّقَ النَّاسُ عَلَيْهِ فَلَمْ يَبْلُغْ ذَلِكَ وَفَاءَ دَيْنِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُذُوا مَا وَجَدْتُمْ وَلَيْسَ لَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏\hadithno{3469}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1556)}\hadithtrans{Narrated Abu Sa’id Al Khudri :In the time of the Messenger of Allah (ﷺ) a man suffered loss affecting fruits he had bought and owed a large debt, so the Messenger of Allah (ﷺ) said: Give him sadaqah (alms). So the people gave him sadaqah (alms), but as that was not enough to pay the debt in full, the Messenger of Allah (ﷺ) said: Take what you find. But that is all you may have}}
\hadithdefcmd{abudawud}{3470}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، وَأَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، - الْمَعْنَى - أَنَّ أَبَا الزُّبَيْرِ الْمَكِّيَّ، أَخْبَرَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ بِعْتَ مِنْ أَخِيكَ تَمْرًا فَأَصَابَتْهَا جَائِحَةٌ فَلاَ يَحِلُّ لَكَ أَنْ تَأْخُذَ مِنْهُ شَيْئًا بِمَ تَأْخُذُ مَالَ أَخِيكَ بِغَيْرِ حَقٍّ ‏"‏ ‏.‏\hadithno{3470}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1554)}\hadithtrans{Narrated Jabir bin ‘Abdullah :The Messenger of Allah (ﷺ) as saying: If you were to sell dried dates to your brother and they were smitten by blight, it will not be allowable for you to take your brother's property unjustly}}
\hadithdefcmd{abudawud}{3471}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عُثْمَانُ بْنُ الْحَكَمِ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ الْجَوَائِحُ كُلُّ ظَاهِرٍ مُفْسِدٍ مِنْ مَطَرٍ أَوْ بَرْدٍ أَوْ جَرَادٍ أَوْ رِيحٍ أَوْ حَرِيقٍ ‏.‏\hadithno{3471}\hadithgrade{Al-Albani: Hasan Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Maqtu; Shuaib Al Arnaut: Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ata said:Blight means anything which obviously damages (the crop), by rain, hail, locust, blast of wind, or fire}}
\hadithdefcmd{abudawud}{3472}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عُثْمَانُ بْنُ الْحَكَمِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ لاَ جَائِحَةَ فِيمَا أُصِيبَ دُونَ ثُلُثِ رَأْسِ الْمَالِ - قَالَ يَحْيَى - وَذَلِكَ فِي سُنَّةِ الْمُسْلِمِينَ ‏.‏\hadithno{3472}\hadithgrade{Al-Albani: Hasan Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Maqtu; Shuaib Al Arnaut: Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Yahya b. Sa'id said:Blight is not effective when less than one-third of goods are damaged. Yayha said: That has been the established practice of Muslims}}
\hadithdefcmd{abudawud}{3473}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ لِيُمْنَعَ بِهِ الْكَلأُ ‏"‏ ‏.‏\hadithno{3473}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Excess water should not be withheld so as to prevent (cattle) by it from grass}}
\hadithdefcmd{abudawud}{3474}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ رَجُلٌ مَنَعَ ابْنَ السَّبِيلِ فَضْلَ مَاءٍ عِنْدَهُ وَرَجُلٌ حَلَفَ عَلَى سِلْعَةٍ بَعْدَ الْعَصْرِ - يَعْنِي كَاذِبًا - وَرَجُلٌ بَايَعَ إِمَامًا فَإِنْ أَعْطَاهُ وَفَى لَهُ وَإِنْ لَمْ يُعْطِهِ لَمْ يَفِ لَهُ ‏"‏ ‏.‏\hadithno{3474}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2672) Sahih Muslim (108)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: There are three people who Allah will not address on the Day of Judgement: a man who prevents traveller from the excess water which he has with him; and a man who swears for the goods (for sale) after the afternoon prayer, that is, (he swears) falsely; and a man who takes the oath of allegiance to a ruler (imam); if he gives him (something), he fullfils (the oath of allegiance) to him, if he does not give him (anything), he does not fulfill it}}
\hadithdefcmd{abudawud}{3475}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ ‏"‏ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏ وَقَالَ فِي السِّلْعَةِ ‏"‏ بِاللَّهِ لَقَدْ أُعْطِيَ بِهَا كَذَا وَكَذَا فَصَدَّقَهُ الآخَرُ فَأَخَذَهَا ‏"‏ ‏.‏\hadithno{3475}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2672) Sahih Muslim (108)}\hadithtrans{The tradition mentioned above has also been related by al-'Amash to the same effect through a different chain of narrators. This version adds:"He used: 'Not purify them ; grievously will be their penalty.'" He said about (selling) the goods: I swear by Allah, I was given (the price) so and so for it. The other man considered it to be correct and bought it}}
\hadithdefcmd{abudawud}{3476}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسٌ، عَنْ سَيَّارِ بْنِ مَنْظُورٍ، - رَجُلٍ مِنْ بَنِي فَزَارَةَ - عَنْ أَبِيهِ، عَنِ امْرَأَةٍ، يُقَالُ لَهَا بُهَيْسَةُ عَنْ أَبِيهَا، قَالَتِ اسْتَأْذَنَ أَبِي النَّبِيَّ صلى الله عليه وسلم فَدَخَلَ بَيْنَهُ وَبَيْنَ قَمِيصِهِ فَجَعَلَ يُقَبِّلُ وَيَلْتَزِمُ ثُمَّ قَالَ يَا نَبِيَّ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ ‏"‏ الْمَاءُ ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ ‏"‏ الْمِلْحُ ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ ‏"‏ أَنْ تَفْعَلَ الْخَيْرَ خَيْرٌ لَكَ ‏"‏ ‏.‏\hadithno{3476}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buhaisah:On the authority of her father: My father asked the Prophet (ﷺ) for permission (to kiss his body). (When he was given permission), lifting his shirt he approached his body, and began to kiss and stick to him. He then asked: Prophet of Allah, what is the thing withholding of which is not lawful ? He replied: Water. He asked: Prophet of Allah, what is the thing withholding of which is not lawful ? He replied: Salt. He again asked: Prophet of Allah, what is the thing withholding of which is not lawful ? He said: That you do a good work is better for you}}
\hadithdefcmd{abudawud}{3477}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ اللُّؤْلُؤِيُّ، أَخْبَرَنَا حَرِيزُ بْنُ عُثْمَانَ، عَنْ حَبَّانَ بْنِ زَيْدٍ الشَّرْعَبِيِّ، عَنْ رَجُلٍ، مِنْ قَرْنٍ ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا حَرِيزُ بْنُ عُثْمَانَ، حَدَّثَنَا أَبُو خِدَاشٍ، - وَهَذَا لَفْظُ عَلِيٍّ - عَنْ رَجُلٍ، مِنَ الْمُهَاجِرِينَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ثَلاَثًا أَسْمَعُهُ يَقُولُ ‏ "‏ الْمُسْلِمُونَ شُرَكَاءُ فِي ثَلاَثٍ فِي الْكَلإِ وَالْمَاءِ وَالنَّارِ ‏"‏ ‏.‏\hadithno{3477}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A man: A man from the immigrants of the Companions of the Prophet (ﷺ) said: I participated in battle three times along with the Prophet (ﷺ). I heard him say: Muslims have common share in three (things). grass, water and fire}}
\hadithdefcmd{abudawud}{3478}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الْمِنْهَالِ، عَنْ إِيَاسِ بْنِ عَبْدٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ فَضْلِ الْمَاءِ ‏.‏\hadithno{3478}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Iyas ibn Abd: The Messenger of Allah (ﷺ) forbade the sale of excess water}}
\hadithdefcmd{abudawud}{3479}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، ح وَحَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، وَعَلِيُّ بْنُ بَحْرٍ، قَالاَ حَدَّثَنَا عِيسَى، وَقَالَ، إِبْرَاهِيمُ أَخْبَرَنَا عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْكَلْبِ وَالسِّنَّوْرِ ‏.‏\hadithno{3479}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) forbade payment for dog and cat}}
\hadithdefcmd{abudawud}{3480}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا عُمَرُ بْنُ زَيْدٍ الصَّنْعَانِيُّ، أَنَّهُ سَمِعَ أَبَا الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْهِرَّةِ ‏.‏\hadithno{3480}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) forbade payment for cat}}
\hadithdefcmd{abudawud}{3481}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏\hadithno{3481}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5761) Sahih Muslim (1567)}\hadithtrans{Narrated Abu Mas'ud:The Prophet (ﷺ) forbade the price paid for a dog, the hire paid to prostitute, and the gift given to a soothsayer}}
\hadithdefcmd{abudawud}{3482}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ عَبْدِ الْكَرِيمِ، عَنْ قَيْسِ بْنِ حَبْتَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَإِنْ جَاءَ يَطْلُبُ ثَمَنَ الْكَلْبِ فَامْلأْ كَفَّهُ تُرَابًا ‏.‏\hadithno{3482}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) forbade the price paid for a dog; if someone comes to ask for the price of a dog, fill his hand-palm with dust}}
\hadithdefcmd{abudawud}{3483}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي عَوْنُ بْنُ أَبِي جُحَيْفَةَ، أَنَّ أَبَاهُ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْكَلْبِ ‏.‏\hadithno{3483}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Juhaifah:The Messenger of Allah (ﷺ)forbade the price paid for a dog}}
\hadithdefcmd{abudawud}{3484}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مَعْرُوفُ بْنُ سُوَيْدٍ الْجُذَامِيُّ، أَنَّ عُلَىَّ بْنَ رَبَاحٍ اللَّخْمِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ ثَمَنُ الْكَلْبِ وَلاَ حُلْوَانُ الْكَاهِنِ وَلاَ مَهْرُ الْبَغِيِّ ‏"‏ ‏.‏\hadithno{3484}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The price paid for a dog, the price given to a soothsayer, and the hire paid to a prostitute are not lawful}}
\hadithdefcmd{abudawud}{3485}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الْوَهَّابِ بْنِ بُخْتٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ حَرَّمَ الْخَمْرَ وَثَمَنَهَا وَحَرَّمَ الْمَيْتَةَ وَثَمَنَهَا وَحَرَّمَ الْخِنْزِيرَ وَثَمَنَهُ ‏"‏ ‏.‏\hadithno{3485}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Allah forbade wine and the price paid for it, and forbade dead meat and the price paid for it, and forbade swine and the price paid for it}}
\hadithdefcmd{abudawud}{3486}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَامَ الْفَتْحِ وَهُوَ بِمَكَّةَ ‏"‏ إِنَّ اللَّهَ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهُ يُطْلَى بِهَا السُّفُنُ وَيُدْهَنُ بِهَا الْجُلُودُ وَيَسْتَصْبِحُ بِهَا النَّاسُ فَقَالَ ‏"‏ لاَ هُوَ حَرَامٌ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ إِنَّ اللَّهَ لَمَّا حَرَّمَ عَلَيْهِمْ شُحُومَهَا أَجْمَلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏\hadithno{3486}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari (2236) Sahih Muslim (1581)}\hadithtrans{Narrated Jabir bin ‘Abdullah :That he heard the Messenger of Allah (ﷺ) say in the year of the Conquest when he was in Mecca: Allah has forbidden the sale of wine, animals which have dead natural death, swine and idols. He was asked: Messenger of Allah, what do you think of the fat of animals which had died a natural death, for it was used for caulking ships, greasing skins, and making oil for lamps? He replies: No, it is forbidden. Thereafter, the Messenger of Allah (ﷺ) said: May Allah curse the Jews! When Allah declared the fat of such animals lawful, they melted it, then sold it, and enjoyed the price they received}}
\hadithdefcmd{abudawud}{3487}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، قَالَ كَتَبَ إِلَىَّ عَطَاءٌ عَنْ جَابِرٍ، نَحْوَهُ لَمْ يَقُلْ ‏ "‏ هُوَ حَرَامٌ ‏"‏ ‏.‏\hadithno{3487}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2236) Sahih Muslim (1581)}\hadithtrans{Yazid b. Abi Habib said:Jabir wrote to me a similar tradition. But he did not say in this version "It is forbidden}}
\hadithdefcmd{abudawud}{3488}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ بِشْرَ بْنَ الْمُفَضَّلِ، وَخَالِدَ بْنَ عَبْدِ اللَّهِ، حَدَّثَاهُمُ - الْمَعْنَى، - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ بَرَكَةَ، قَالَ مُسَدَّدٌ فِي حَدِيثِ خَالِدِ بْنِ عَبْدِ اللَّهِ عَنْ بَرَكَةَ أَبِي الْوَلِيدِ، ثُمَّ اتَّفَقَا - عَنِ ابْنِ عَبَّاسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم جَالِسًا عِنْدَ الرُّكْنِ - قَالَ - فَرَفَعَ بَصَرَهُ إِلَى السَّمَاءِ فَضَحِكَ فَقَالَ ‏"‏ لَعَنَ اللَّهُ الْيَهُودَ ‏"‏ ‏.‏ ثَلاَثًا ‏"‏ إِنَّ اللَّهَ حَرَّمَ عَلَيْهِمُ الشُّحُومَ فَبَاعُوهَا وَأَكَلُوا أَثْمَانَهَا وَإِنَّ اللَّهَ إِذَا حَرَّمَ عَلَى قَوْمٍ أَكْلَ شَىْءٍ حَرَّمَ عَلَيْهِمْ ثَمَنَهُ ‏"‏ ‏.‏ وَلَمْ يَقُلْ فِي حَدِيثِ خَالِدِ بْنِ عَبْدِ اللَّهِ الطَّحَّانِ ‏"‏ رَأَيْتُ ‏"‏ ‏.‏ وَقَالَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ ‏"‏ ‏.‏\hadithno{3488}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:I saw the Messenger of Allah (ﷺ) sitting neat the Black stone (or at a corner of the Ka'bah). He said: He (the Prophet) raised his eyes towards the heaven, and laughed, and he said: May Allah curse the Jews! He said this three times. Allah declared unlawful for them the fats (of the animals which died a natural death); they sold them and they enjoyed the price they received for them. When Allah declared eating of thing forbidden for the people, He declares it price also forbidden for them. The version of Khalid b. 'Abd Allah al-Tahhan does not have the words "I saw". It has: "May Allah destroy the Jews}}
\hadithdefcmd{abudawud}{3489}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، وَوَكِيعٌ، عَنْ طُعْمَةَ بْنِ عَمْرٍو الْجَعْفَرِيِّ، عَنْ عُمَرَ بْنِ بَيَانٍ التَّغْلِبِيِّ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَاعَ الْخَمْرَ فَلْيُشَقِّصِ الْخَنَازِيرَ ‏"‏ ‏.‏\hadithno{3489}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: The Prophet (ﷺ) said: He who sold wine should shear the flesh of swine}}
\hadithdefcmd{abudawud}{3490}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتِ الآيَاتُ الأَوَاخِرُ مِنْ سُورَةِ الْبَقَرَةِ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَرَأَهُنَّ عَلَيْنَا وَقَالَ ‏ "‏ حُرِّمَتِ التِّجَارَةُ فِي الْخَمْرِ ‏"‏ ‏.‏\hadithno{3490}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2226) Sahih Muslim (1580)}\hadithtrans{Narrated 'Aishah:When the last verses of Surat al-Baqarah were revealed, the Messenger of Allah (ﷺ) came out and recited them to us and siad: Trading in wine has been forbidden}}
\hadithdefcmd{abudawud}{3491}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ الآيَاتُ الأَوَاخِرُ فِي الرِّبَا ‏.‏\hadithno{3491}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1580)}\hadithtrans{The tradition mentioned above has also been transmitted by al-A'mash to the same effect through a different chain of narrators. This version adds:"The last verses about usury}}
\hadithdefcmd{abudawud}{3492}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏\hadithno{3492}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2136) Sahih Muslim (1526)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) as saying: If anyone buys grain, he must not sell it till receives it in full}}
\hadithdefcmd{abudawud}{3493}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ كُنَّا فِي زَمَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَبْتَاعُ الطَّعَامَ فَيَبْعَثُ عَلَيْنَا مَنْ يَأْمُرُنَا بِانْتِقَالِهِ مِنَ الْمَكَانِ الَّذِي ابْتَعْنَاهُ فِيهِ إِلَى مَكَانٍ سِوَاهُ قَبْلَ أَنْ نَبِيعَهُ - يَعْنِي - جُزَافًا ‏.‏\hadithno{3493}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1527)}\hadithtrans{Narrated Ibn 'Umar: During the time of Messenger of Allah (ﷺ) we used to buy grain, and he sent a man to us who ordered us to move it from the spot where we had bought it to some other place, before we sold it without weighing or measuring it}}
\hadithdefcmd{abudawud}{3494}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانُوا يَتَبَايَعُونَ الطَّعَامَ جُزَافًا بِأَعْلَى السُّوقِ فَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعُوهُ حَتَّى يَنْقُلُوهُ ‏.‏\hadithno{3494}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1526)}\hadithtrans{Ibn 'Umar said: They (the people) used to buy grain in the upper part of the market in the same spot without measuring or weighing it. The Messenger of Allah (ﷺ) forbade them to sell it there before removing it}}
\hadithdefcmd{abudawud}{3495}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا عَمْرٌو، عَنِ الْمُنْذِرِ بْنِ عُبَيْدٍ الْمَدِينِيِّ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَبِيعَ أَحَدٌ طَعَامًا اشْتَرَاهُ بِكَيْلٍ حَتَّى يَسْتَوْفِيَهُ ‏.‏\hadithno{3495}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) forbade to sell grain which one buys by measurement until one receives it in full}}
\hadithdefcmd{abudawud}{3496}{حَدَّثَنَا أَبُو بَكْرٍ، وَعُثْمَانُ، ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَكْتَالَهُ ‏"‏ ‏.‏ زَادَ أَبُو بَكْرٍ قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ لِمَ قَالَ أَلاَ تَرَى أَنَّهُمْ يَتَبَايَعُونَ بِالذَّهَبِ وَالطَّعَامُ مُرَجًّى ‏.‏\hadithno{3496}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1525)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) as saying: If anyone buys grain, he should not sell it until he measures it. Abu Bakr added in his version: I asked Ibn 'Abbas: Why ? He replied: Do you not see that they sell (grain) for gold, but the grain is still with the seller}}
\hadithdefcmd{abudawud}{3497}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، - وَهَذَا لَفْظُ مُسَدَّدٍ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا اشْتَرَى أَحَدُكُمْ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَقْبِضَهُ ‏"‏ ‏.‏ قَالَ سُلَيْمَانُ بْنُ حَرْبٍ ‏"‏ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏ زَادَ مُسَدَّدٌ قَالَ وَقَالَ ابْنُ عَبَّاسٍ وَأَحْسِبُ أَنَّ كُلَّ شَىْءٍ مِثْلُ الطَّعَامِ ‏.‏\hadithno{3497}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2135) Sahih Muslim (1525)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) as saying: If anyone buys a grain, he should not sell it until he takes possession of it. Sulaiman b. Harb said: Until he receives it in full. Musaddad added: Ibn 'Abbas said: And I think that everything is like grain}}
\hadithdefcmd{abudawud}{3498}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ النَّاسَ يُضْرَبُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا اشْتَرَوُا الطَّعَامَ جُزَافًا أَنْ يَبِيعُوهُ حَتَّى يُبْلِغَهُ إِلَى رَحْلِهِ ‏.‏\hadithno{3498}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6852) Sahih Muslim (1527)}\hadithtrans{Narrated Ibn 'Abbas:I saw that during the time of the Messenger of Allah (ﷺ) the people were beaten when they bought grain on the same spot and sold it there without moving it to their houses}}
\hadithdefcmd{abudawud}{3499}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ الْوَهْبِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ أَبِي الزِّنَادِ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عُمَرَ، قَالَ ابْتَعْتُ زَيْتًا فِي السُّوقِ فَلَمَّا اسْتَوْجَبْتُهُ لِنَفْسِي لَقِيَنِي رَجُلٌ فَأَعْطَانِي بِهِ رِبْحًا حَسَنًا فَأَرَدْتُ أَنْ أَضْرِبَ عَلَى يَدِهِ فَأَخَذَ رَجُلٌ مِنْ خَلْفِي بِذِرَاعِي فَالْتَفَتُّ فَإِذَا زَيْدُ بْنُ ثَابِتٍ فَقَالَ لاَ تَبِعْهُ حَيْثُ ابْتَعْتَهُ حَتَّى تَحُوزَهُ إِلَى رَحْلِكَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُبَاعَ السِّلَعُ حَيْثُ تُبْتَاعُ حَتَّى يَحُوزَهَا التُّجَّارُ إِلَى رِحَالِهِمْ ‏.‏\hadithno{3499}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn Umar: I bought olive oil in the market. When I became its owner, a man met me and offered good profit for it. I intended to settle the bargain with him, but a man caught hold of my hand from behind. When I turned I found that he was Zayd ibn Thabit. He said: Do not sell it on the spot where you have bought it until you take it to your house, for the Messenger of Allah (ﷺ) forbade to sell the goods where they are bought until the tradesmen take them to their houses}}
\hadithdefcmd{abudawud}{3500}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، ذَكَرَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ يُخْدَعُ فِي الْبَيْعِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏ ‏.‏ فَكَانَ الرَّجُلُ إِذَا بَايَعَ يَقُولُ لاَ خِلاَبَةَ ‏.‏\hadithno{3500}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2117) Sahih Muslim (1533)}\hadithtrans{Narrated Ibn 'Umar:A man told the Messenger of Allah (ﷺ) that he was being deceived in business transactions. The Messenger of Allah (ﷺ) then said: When you make a bargain, say: There is no attempt to deceive. So when the man made a bargain, he said: There is no attempt to deceive}}
\hadithdefcmd{abudawud}{3501}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَرُزِّيُّ، وَإِبْرَاهِيمُ بْنُ خَالِدٍ أَبُو ثَوْرٍ الْكَلْبِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، - قَالَ مُحَمَّدٌ عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ - أَخْبَرَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ يَبْتَاعُ وَفِي عُقْدَتِهِ ضَعْفٌ فَأَتَى أَهْلُهُ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا نَبِيَّ اللَّهِ احْجُرْ عَلَى فُلاَنٍ فَإِنَّهُ يَبْتَاعُ وَفِي عُقْدَتِهِ ضَعْفٌ فَدَعَاهُ النَّبِيُّ صلى الله عليه وسلم فَنَهَاهُ عَنِ الْبَيْعِ فَقَالَ يَا نَبِيَّ اللَّهِ إِنِّي لاَ أَصْبِرُ عَنِ الْبَيْعِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ كُنْتَ غَيْرَ تَارِكٍ الْبَيْعَ فَقُلْ هَاءَ وَهَاءَ وَلاَ خِلاَبَةَ ‏"‏ ‏.‏ قَالَ أَبُو ثَوْرٍ عَنْ سَعِيدٍ ‏.‏\hadithno{3501}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: During the time of the Messenger of Allah (ﷺ) a man used to buy (goods), and he was weak in his intellect. His people came to the Prophet of Allah (ﷺ) and said: Prophet of Allah, stop so-and-so (to make a bargain) for he buys (goods), but he is weak in his intellect. So the Prophet (ﷺ) called on him and forbade him to make a bargain. He said: Prophet of Allah, I cannot keep away myself from business transactions. Thereupon the Messenger of Allah (ﷺ) said: If you cannot give up making a bargain , then say: Take , and give, and there is no attempt to deceive}}
\hadithdefcmd{abudawud}{3502}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ أَنَّهُ بَلَغَهُ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْعُرْبَانِ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ - فِيمَا نَرَى وَاللَّهُ أَعْلَمُ - أَنْ يَشْتَرِيَ الرَّجُلُ الْعَبْدَ أَوْ يَتَكَارَى الدَّابَّةَ ثُمَّ يَقُولُ أُعْطِيكَ دِينَارًا عَلَى أَنِّي إِنْ تَرَكْتُ السِّلْعَةَ أَوِ الْكِرَاءَ فَمَا أَعْطَيْتُكَ لَكَ ‏.‏\hadithno{3502}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather told that the Messenger of Allah (ﷺ) forbade the type of transactions in which earnest money was paid. Malik said: This means, as we think--Allah better knows-that a man buys a slave or hires an animal, and he says: I give you a dinar on condition that if I give up the transaction or hire, what I gave you is yours}}
\hadithdefcmd{abudawud}{3503}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ يَا رَسُولَ اللَّهِ يَأْتِينِي الرَّجُلُ فَيُرِيدُ مِنِّي الْبَيْعَ لَيْسَ عِنْدِي أَفَأَبْتَاعُهُ لَهُ مِنَ السُّوقِ فَقَالَ ‏ "‏ لاَ تَبِعْ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏\hadithno{3503}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hakim ibn Hizam: Hakim asked (the Prophet): Messenger of Allah, a man comes to me and wants me to sell him something which is not in my possession. Should I buy it for him from the market? He replied: Do not sell what you do not possess}}
\hadithdefcmd{abudawud}{3504}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، عَنْ أَبِيهِ، حَتَّى ذَكَرَ عَبْدَ اللَّهِ بْنَ عَمْرٍو قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ سَلَفٌ وَبَيْعٌ وَلاَ شَرْطَانِ فِي بَيْعٍ وَلاَ رِبْحُ مَا لَمْ تَضْمَنْ وَلاَ بَيْعُ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏\hadithno{3504}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather 'Abd Allah b. 'Amr reported the Messenger of Allah (ﷺ) as saying: The proviso of a loan combined with a sale is not allowable, nor two conditions relating to one transaction, nor profit arising from something which is not in one's charge, nor selling what is not in your possession}}
\hadithdefcmd{abudawud}{3505}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ زَكَرِيَّا، حَدَّثَنَا عَامِرٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بِعْتُهُ - يَعْنِي بَعِيرَهُ - مِنَ النَّبِيِّ صلى الله عليه وسلم وَاشْتَرَطْتُ حُمْلاَنَهُ إِلَى أَهْلِي قَالَ فِي آخِرِهِ ‏ "‏ تُرَانِي إِنَّمَا مَاكَسْتُكَ لأَذْهَبَ بِجَمَلِكَ خُذْ جَمَلَكَ وَثَمَنَهُ فَهُمَا لَكَ ‏"‏ ‏.‏\hadithno{3505}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2718) Sahih Muslim (715 After 1599)}\hadithtrans{Narrated Jabir bin ‘Abdullah :I sold it, that is, camel, to the Prophet (ﷺ), but I made the stipulation that I should be allowed to ride it to home. At the end he (the Prophet) said: Do you think that I made this transaction with you so that I take your camel ? Take your camel and its price; both are yours}}
\hadithdefcmd{abudawud}{3506}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُهْدَةُ الرَّقِيقِ ثَلاَثَةُ أَيَّامٍ ‏"‏ ‏.‏\hadithno{3506}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Uqbah ibn Amir: The Prophet (ﷺ) said: The contractual obligation of a slave is three days}}
\hadithdefcmd{abudawud}{3507}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ إِنْ وَجَدَ دَاءً فِي الثَّلاَثِ اللَّيَالِي رُدَّ بِغَيْرِ بَيِّنَةٍ وَإِنْ وَجَدَ دَاءً بَعْدَ الثَّلاَثِ كُلِّفَ الْبَيِّنَةَ أَنَّهُ اشْتَرَاهُ وَبِهِ هَذَا الدَّاءُ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا التَّفْسِيرُ مِنْ كَلاَمِ قَتَادَةَ ‏.‏\hadithno{3507}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Qatadah through a different chain of narrators to the same effect. This version adds:"If he finds defect (in the slave) within three days, he may return it without evidence; if he finds a defect after three days, he will be required to produce evidence that he (the slave) had the defect when he bought it." Abu Dawud said: This explanation is from the words of Qatadah}}
\hadithdefcmd{abudawud}{3508}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ مَخْلَدِ بْنِ خُفَافٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَرَاجُ بِالضَّمَانِ ‏"‏ ‏.‏\hadithno{3508}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: Profit follows responsibility}}
\hadithdefcmd{abudawud}{3509}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الْفِرْيَابِيُّ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مَخْلَدِ بْنِ خُفَافٍ الْغِفَارِيِّ، قَالَ كَانَ بَيْنِي وَبَيْنَ أُنَاسٍ شَرِكَةٌ فِي عَبْدٍ فَاقْتَوَيْتُهُ وَبَعْضُنَا غَائِبٌ فَأَغَلَّ عَلَىَّ غَلَّةً فَخَاصَمَنِي فِي نَصِيبِهِ إِلَى بَعْضِ الْقُضَاةِ فَأَمَرَنِي أَنْ أَرُدَّ الْغَلَّةَ فَأَتَيْتُ عُرْوَةَ بْنَ الزُّبَيْرِ فَحَدَّثْتُهُ فَأَتَاهُ عُرْوَةُ فَحَدَّثَهُ عَنْ عَائِشَةَ - رَضِيَ اللَّهُ عَنْهَا - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَرَاجُ بِالضَّمَانِ ‏"‏ ‏.‏\hadithno{3509}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Makhlad ibn Khufaf al-Ghifari: I and some people were partners in a slave. I employed him on some work in the absence of one of the partners. He got earnings for me. He disputed me and the case of his claim to his share in the earnings to a judge, who ordered me to return the earnings (i.e. his share) to him. I then came to Urwah ibn az-Zubayr, and related the matter to him. Urwah then came to him and narrated to him a tradition from the Messenger of Allah (ﷺ) on the authority of Aisha: Profit follows responsibility}}
\hadithdefcmd{abudawud}{3510}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَرْوَانَ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُسْلِمُ بْنُ خَالِدٍ الزَّنْجِيُّ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَجُلاً، ابْتَاعَ غُلاَمًا فَأَقَامَ عِنْدَهُ مَا شَاءَ اللَّهُ أَنْ يُقِيمَ ثُمَّ وَجَدَ بِهِ عَيْبًا فَخَاصَمَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَرَدَّهُ عَلَيْهِ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ قَدِ اسْتَغَلَّ غُلاَمِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَرَاجُ بِالضَّمَانِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا إِسْنَادٌ لَيْسَ بِذَاكَ ‏.‏\hadithno{3510}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A man bought a slave, and he remained with him as long as Allah wished him to remain. He then found defect in him. He brought his dispute with him to the Prophet (ﷺ) and he returned him to him. The man said: Messenger of Allah, my slave earned some wages. The Messenger of Allah (ﷺ) then said: Profit follows responsibility. Abu Dawud said: This chain of narrators (of this version) is not reliable}}
\hadithdefcmd{abudawud}{3511}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنْ أَبِي عُمَيْسٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ قَيْسِ بْنِ مُحَمَّدِ بْنِ الأَشْعَثِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ اشْتَرَى الأَشْعَثُ رَقِيقًا مِنْ رَقِيقِ الْخُمُسِ مِنْ عَبْدِ اللَّهِ بِعِشْرِينَ أَلْفًا فَأَرْسَلَ عَبْدُ اللَّهِ إِلَيْهِ فِي ثَمَنِهِمْ فَقَالَ إِنَّمَا أَخَذْتُهُمْ بِعَشْرَةِ آلاَفٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ فَاخْتَرْ رَجُلاً يَكُونُ بَيْنِي وَبَيْنَكَ ‏.‏ قَالَ الأَشْعَثُ أَنْتَ بَيْنِي وَبَيْنَ نَفْسِكَ ‏.‏ قَالَ عَبْدُ اللَّهِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا اخْتَلَفَ الْبَيِّعَانِ وَلَيْسَ بَيْنَهُمَا بَيِّنَةٌ فَهُوَ مَا يَقُولُ رَبُّ السِّلْعَةِ أَوْ يَتَتَارَكَانِ ‏"‏ ‏.‏\hadithno{3511}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: Muhammad ibn al-Ash'ath said: Al-Ash'ath bought slaves of booty from Abdullah ibn Mas'ud for twenty thousand (dirhams. Abdullah asked him for payment of their price. He said: I bought them for ten thousand (dirhams). Abdullah said: Appoint a man who may adjudicate between me and you. Al-Ash'ath said: (I appoint) you between me and yourself. Abdullah said: I heard the Messenger of Allah (ﷺ) say: If both parties in a business transaction differ (on the price of an article), and they have witness between them, the statement of the owner of the article will be accepted (as correct) or they may annul the transaction}}
\hadithdefcmd{abudawud}{3512}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا ابْنُ أَبِي لَيْلَى، أَنَّ الْقَاسِمَ بْنَ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، أَنَّ ابْنَ مَسْعُودٍ، بَاعَ مِنَ الأَشْعَثِ بْنِ قَيْسٍ رَقِيقًا فَذَكَرَ مَعْنَاهُ وَالْكَلاَمُ يَزِيدُ وَيَنْقُصُ ‏.‏\hadithno{3512}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Qasim b. 'Abd al-Rahman reported on the authority of his father:Ibn Mas'ud sold slaves to al-Ash'ath b. Qais. He then narrated the rest of the tradition to the same effect with some variation of words}}
\hadithdefcmd{abudawud}{3513}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشُّفْعَةُ فِي كُلِّ شِرْكٍ رَبْعَةٍ أَوْ حَائِطٍ لاَ يَصْلُحُ أَنْ يَبِيعَ حَتَّى يُؤْذِنَ شَرِيكَهُ فَإِنْ بَاعَ فَهُوَ أَحَقُّ بِهِ حَتَّى يُؤْذِنَهُ ‏"‏ ‏.‏\hadithno{3513}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1608)}\hadithtrans{Narrated Jabir:The Messenger of Allah (ﷺ) as saying: There is the right of option regarding everything which is shared, whether a dwelling or a garden. It is not lawful to sell before informing one's partner, but if he sells without informing him, he has the greatest right to it}}
\hadithdefcmd{abudawud}{3514}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ إِنَّمَا جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الشُّفْعَةَ فِي كُلِّ مَالٍ لَمْ يُقْسَمْ فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِفَتِ الطُّرُقُ فَلاَ شُفْعَةَ ‏.‏\hadithno{3514}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6976)}\hadithtrans{Narrated Jabir bin ‘Abdullah :The Messenger of Allah (ﷺ) decreed the right to buy the neighboring property applicable to everything which is not divided, but when boundaries are fixed and separate roads made, there is no option}}
\hadithdefcmd{abudawud}{3515}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، أَوْ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَوْ عَنْهُمَا جَمِيعًا عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قُسِّمَتِ الأَرْضُ وَحُدَّتْ فَلاَ شُفْعَةَ فِيهَا ‏"‏ ‏.‏\hadithno{3515}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When land has been divided and boundaries have been set up, there is no right of pre-emption in it}}
\hadithdefcmd{abudawud}{3516}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، سَمِعَ عَمْرَو بْنَ الشَّرِيدِ، سَمِعَ أَبَا رَافِعٍ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏ ‏.‏\hadithno{3516}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6977)}\hadithtrans{Narrated Abu Rafi':The Messenger of Allah (ﷺ) as saying: A neighbor has the best claim to the house or land of the neighbor}}
\hadithdefcmd{abudawud}{3517}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ جَارُ الدَّارِ أَحَقُّ بِدَارِ الْجَارِ أَوِ الأَرْضِ ‏"‏ ‏.‏\hadithno{3517}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Samurah: The Prophet (ﷺ) said: A neighbour has the best claim to the house or land of the neighbour}}
\hadithdefcmd{abudawud}{3518}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْجَارُ أَحَقُّ بِشُفْعَةِ جَارِهِ يُنْتَظَرُ بِهَا وَإِنْ كَانَ غَائِبًا إِذَا كَانَ طَرِيقُهُمَا وَاحِدًا ‏"‏ ‏.‏\hadithno{3518}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: The neighbour is most entitled to the right of pre-emption, and he should wait for its exercise even if he is absent, when the two properties have one road}}
\hadithdefcmd{abudawud}{3519}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، - الْمَعْنَى - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أَفْلَسَ فَأَدْرَكَ الرَّجُلُ مَتَاعَهُ بِعَيْنِهِ فَهُوَ أَحَقُّ بِهِ مِنْ غَيْرِهِ ‏"‏ ‏.‏\hadithno{3519}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2402) Sahih Muslim (1559)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: If anyone becomes insolvent and the man (i.e. creditor) finds his very property with him, he is more entitled to it than anyone else}}
\hadithdefcmd{abudawud}{3520}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ بَاعَ مَتَاعًا فَأَفْلَسَ الَّذِي ابْتَاعَهُ وَلَمْ يَقْبِضِ الَّذِي بَاعَهُ مِنْ ثَمَنِهِ شَيْئًا فَوَجَدَ مَتَاعَهُ بِعَيْنِهِ فَهُوَ أَحَقُّ بِهِ وَإِنْ مَاتَ الْمُشْتَرِي فَصَاحِبُ الْمَتَاعِ أُسْوَةُ الْغُرَمَاءِ ‏"‏ ‏.‏\hadithno{3520}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuBakr ibn AbdurRahman ibn al-Harith ibn Hisham: The Prophet (ﷺ) said: If a man sells (his) property and the man who buys it becomes insolvent, and the seller does not receive the price of the property he had sold, but finds his very property with him (i.e. the buyer), he is more entitled to it (than others). If the buyer dies, then the owner of the property is equal to the creditors}}
\hadithdefcmd{abudawud}{3521}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ وَهْبٍ - أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مَعْنَى حَدِيثِ مَالِكٍ زَادَ ‏ "‏ وَإِنْ قَضَى مِنْ ثَمَنِهَا شَيْئًا فَهُوَ أُسْوَةُ الْغُرَمَاءِ فِيهَا ‏"‏ ‏.‏\hadithno{3521}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Bakr b. 'Adb al-Rahman b. al-Harith b. Hisham from Messenger of Allah (ﷺ) through a different chain of narrators to the same effect as narrated by Malik. This version adds:"If he paid something from the price (of the property), then he will be equal to the creditors in it}}
\hadithdefcmd{abudawud}{3522}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْجَبَّارِ، - يَعْنِي الْخَبَائِرِيَّ - حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عَيَّاشٍ - عَنِ الزُّبَيْدِيِّ، - قَالَ أَبُو دَاوُدَ وَهُوَ مُحَمَّدُ بْنُ الْوَلِيدِ أَبُو الْهُذَيْلِ الْحِمْصِيُّ - عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ قَالَ ‏ "‏ فَإِنْ كَانَ قَضَاهُ مِنْ ثَمَنِهَا شَيْئًا فَمَا بَقِيَ فَهُوَ أُسْوَةُ الْغُرَمَاءِ وَأَيُّمَا امْرِئٍ هَلَكَ وَعِنْدَهُ مَتَاعُ امْرِئٍ بِعَيْنِهِ اقْتَضَى مِنْهُ شَيْئًا أَوْ لَمْ يَقْتَضِ فَهُوَ أُسْوَةُ الْغُرَمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ مَالِكٍ أَصَحُّ ‏.‏\hadithno{3522}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A similar tradition (to the No. 3513) has been transmitted by AbuHurayrah from the Prophet (ﷺ). This version has:If he paid something from its price, then he will be equal to the creditors in the remaining price. If a man dies and he has the very property of a man (i.e. seller), he is equal to the creditors whether he (the buyer) pays him (the price) or not. Abu Dawud said: Malik's version of this tradition is sounder}}
\hadithdefcmd{abudawud}{3523}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، هُوَ الطَّيَالِسِيُّ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ أَبِي الْمُعْتَمِرِ، عَنْ عُمَرَ بْنِ خَلْدَةَ، قَالَ أَتَيْنَا أَبَا هُرَيْرَةَ فِي صَاحِبٍ لَنَا أَفْلَسَ فَقَالَ لأَقْضِيَنَّ فِيكُمْ بِقَضَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَفْلَسَ أَوْ مَاتَ فَوَجَدَ رَجُلٌ مَتَاعَهُ بِعَيْنِهِ فَهُوَ أَحَقُّ بِهِ ‏"‏ ‏.‏\hadithno{3523}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umar ibn Khaldah said:We came to AbuHurayrah who had become insolvent. He said: I shall decide between you on the basis of the decision of the Messenger of Allah (ﷺ): If anyone becomes insolvent or dies and the man (the seller) finds his very property with him, he is more entitled to it (than others)}}
\hadithdefcmd{abudawud}{3524}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُوسَى، حَدَّثَنَا أَبَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنِ الشَّعْبِيِّ، - قَالَ عَنْ أَبَانَ، أَنَّ عَامِرًا الشَّعْبِيَّ، - حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ وَجَدَ دَابَّةً قَدْ عَجَزَ عَنْهَا أَهْلُهَا أَنْ يَعْلِفُوهَا فَسَيَّبُوهَا فَأَخَذَهَا فَأَحْيَاهَا فَهِيَ لَهُ ‏"‏ ‏.‏ قَالَ فِي حَدِيثِ أَبَانَ قَالَ عُبَيْدُ اللَّهِ فَقُلْتُ عَمَّنْ قَالَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا حَدِيثُ حَمَّادٍ وَهُوَ أَبْيَنُ وَأَتَمُّ ‏.‏\hadithno{3524}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amir ash-Sha'bi: The Prophet (ﷺ) said: If anyone finds an animal whose owners were helpless to provide fodder to it and so they turned it out (of their house), and he took it and looked after it, it will belong to him. Abu Dawud said: This is the tradition of Hammad. It is more plain and perfect}}
\hadithdefcmd{abudawud}{3525}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ حَمَّادٍ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عُبَيْدِ اللَّهِ بْنِ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الشَّعْبِيِّ، يَرْفَعُ الْحَدِيثَ إِلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ تَرَكَ دَابَّةً بِمُهْلِكٍ فَأَحْيَاهَا رَجُلٌ فَهِيَ لِمَنْ أَحْيَاهَا ‏"‏ ‏.‏\hadithno{3525}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated ash-Sha'bi: The Prophet (ﷺ) said: If anyone leaves an animal at a place of perishing and another man brings it to life, it belongs to him who brings it to life}}
\hadithdefcmd{abudawud}{3526}{حَدَّثَنَا هَنَّادٌ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ زَكَرِيَّاءَ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَبَنُ الدَّرِّ يُحْلَبُ بِنَفَقَتِهِ إِذَا كَانَ مَرْهُونًا وَالظَّهْرُ يُرْكَبُ بِنَفَقَتِهِ إِذَا كَانَ مَرْهُونًا وَعَلَى الَّذِي يَرْكَبُ وَيَحْلِبُ النَّفَقَةُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ عِنْدَنَا صَحِيحٌ ‏.‏\hadithno{3526}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2512)}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) as saying: The milk of milch camels may be drunk for payment when in pledge, and the animal may be ridden for payment when it is pledge; payment being made by the one who rides and the one who drinks. Abu Dawud said: In our opinion this is correct}}
\hadithdefcmd{abudawud}{3527}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ لأُنَاسًا مَا هُمْ بِأَنْبِيَاءَ وَلاَ شُهَدَاءَ يَغْبِطُهُمُ الأَنْبِيَاءُ وَالشُّهَدَاءُ يَوْمَ الْقِيَامَةِ بِمَكَانِهِمْ مِنَ اللَّهِ تَعَالَى ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ تُخْبِرُنَا مَنْ هُمْ ‏.‏ قَالَ ‏"‏ هُمْ قَوْمٌ تَحَابُّوا بِرُوحِ اللَّهِ عَلَى غَيْرِ أَرْحَامٍ بَيْنَهُمْ وَلاَ أَمْوَالٍ يَتَعَاطَوْنَهَا فَوَاللَّهِ إِنَّ وُجُوهَهُمْ لَنُورٌ وَإِنَّهُمْ عَلَى نُورٍ لاَ يَخَافُونَ إِذَا خَافَ النَّاسُ وَلاَ يَحْزَنُونَ إِذَا حَزِنَ النَّاسُ ‏"‏ ‏.‏ وَقَرَأَ هَذِهِ الآيَةَ ‏\{‏ أَلاَ إِنَّ أَوْلِيَاءَ اللَّهِ لاَ خَوْفٌ عَلَيْهِمْ وَلاَ هُمْ يَحْزَنُونَ ‏\}‏ ‏.‏\hadithno{3527}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umar ibn al-Khattab: reported the Prophet (ﷺ) as saying: There are people from the servants of Allah who are neither prophets nor martyrs; the prophets and martyrs will envy them on the Day of Resurrection for their rank from Allah, the Most High. They (the people) asked: Tell us, Messenger of Allah, who are they? He replied: They are people who love one another for the spirit of Allah (i.e. the Qur'an), without having any mutual kinship and giving property to one. I swear by Allah, their faces will glow and they will be (sitting) in (pulpits of) light. They will have no fear (on the Day) when the people will have fear, and they will not grieve when the people will grieve. He then recited the following Qur'anic verse: "Behold! Verily for the friends of Allah there is no fear, nor shall they grieve}}
\hadithdefcmd{abudawud}{3528}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَمَّتِهِ، أَنَّهَا سَأَلَتْ عَائِشَةَ رضى الله عنها فِي حِجْرِي يَتِيمٌ أَفَآكُلُ مِنْ مَالِهِ فَقَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَطْيَبِ مَا أَكَلَ الرَّجُلُ مِنْ كَسْبِهِ وَوَلَدُهُ مِنْ كَسْبِهِ ‏"‏ ‏.‏\hadithno{3528}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The aunt of Umarah ibn Umayr asked Aisha: I have an orphan in my guardianship. May I enjoy from his property? She said: The Messenger of Allah (ﷺ) said: The pleasantest things a man enjoys come from what he earns, and his child comes from what he earns}}
\hadithdefcmd{abudawud}{3529}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ وَلَدُ الرَّجُلِ مِنْ كَسْبِهِ مِنْ أَطْيَبِ كَسْبِهِ فَكُلُوا مِنْ أَمْوَالِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ حَمَّادُ بْنُ أَبِي سُلَيْمَانَ زَادَ فِيهِ ‏"‏ إِذَا احْتَجْتُمْ ‏"‏ ‏.‏ وَهُوَ مُنْكَرٌ ‏.‏\hadithno{3529}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) Said: The children of a man come from what he earns, rather they are his pleasantest earning; so enjoy from their property. Abu Dawud said: Hammad b. Abi Sulaiman added in his version: "When you need." But this (addition) is munkar (not authoritative)}}
\hadithdefcmd{abudawud}{3530}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي مَالاً وَوَلَدًا وَإِنَّ وَالِدِي يَجْتَاحُ مَالِي ‏.‏ قَالَ ‏ "‏ أَنْتَ وَمَالُكَ لِوَالِدِكَ إِنَّ أَوْلاَدَكُمْ مِنْ أَطْيَبِ كَسْبِكُمْ فَكُلُوا مِنْ كَسْبِ أَوْلاَدِكُمْ ‏"‏ ‏.‏\hadithno{3530}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: A man came to the Prophet (ﷺ) and said: Messenger of Allah, I have property and children, and my father finishes my property. He replied; You and your property belong to your father; your children come from the pleasantest of what you earn; so enjoy from the earning of your children}}
\hadithdefcmd{abudawud}{3531}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُوسَى بْنِ السَّائِبِ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدَ عَيْنَ مَالِهِ عِنْدَ رَجُلٍ فَهُوَ أَحَقُّ بِهِ وَيَتَّبِعُ الْبَيِّعُ مَنْ بَاعَهُ ‏"‏ ‏.‏\hadithno{3531}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: If anyone finds his very property with a man, he is more entitled to it (than anyone else), and the buyer should pursue the one who sold it}}
\hadithdefcmd{abudawud}{3532}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ هِنْدًا أُمَّ مُعَاوِيَةَ، جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ وَإِنَّهُ لاَ يُعْطِينِي مَا يَكْفِينِي وَبَنِيَّ فَهَلْ عَلَىَّ جُنَاحٌ أَنْ آخُذَ مِنْ مَالِهِ شَيْئًا قَالَ ‏ "‏ خُذِي مَا يَكْفِيكِ وَبَنِيكِ بِالْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{3532}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2211) Sahih Muslim (1714)}\hadithtrans{Narrated 'Aishah:Hind, the mother of Mu'awiyah, came to the Messenger of Allah (ﷺ) and said: 'Abu Sufyan is a stingy person. He does not give me as much (money) as suffices me and my children. Is there any harm to me if I take something from his property ? He said: Take as much as suffices you and your children according to the custom}}
\hadithdefcmd{abudawud}{3533}{حَدَّثَنَا خُشَيْشُ بْنُ أَصْرَمَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ هِنْدٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مُمْسِكٌ فَهَلْ عَلَىَّ مِنْ حَرَجٍ أَنْ أُنْفِقَ عَلَى عِيَالِهِ مِنْ مَالِهِ بِغَيْرِ إِذْنِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ حَرَجَ عَلَيْكِ أَنْ تُنْفِقِي عَلَيْهِمْ بِالْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{3533}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1714)}\hadithtrans{Narrated 'Aishah:Hind came to the Prophet (ﷺ) and said: Messenger of Allah, Abu Sufyan is a stingy person. Is there any harm to me if I spend on his dependants from his property without his permission ? The Prophet (ﷺ) replied: There is no harm to you if you spend according to the custom}}
\hadithdefcmd{abudawud}{3534}{حَدَّثَنَا أَبُو كَامِلٍ، أَنَّ يَزِيدَ بْنَ زُرَيْعٍ، حَدَّثَهُمْ حَدَّثَنَا حُمَيْدٌ، - يَعْنِي الطَّوِيلَ - عَنْ يُوسُفَ بْنِ مَاهَكَ الْمَكِّيِّ، قَالَ كُنْتُ أَكْتُبُ لِفُلاَنٍ نَفَقَةَ أَيْتَامٍ كَانَ وَلِيَّهُمْ فَغَالَطُوهُ بِأَلْفِ دِرْهَمٍ فَأَدَّاهَا إِلَيْهِمْ فَأَدْرَكْتُ لَهُمْ مِنْ مَالِهِمْ مِثْلَيْهَا ‏.‏ قَالَ قُلْتُ أَقْبِضُ الأَلْفَ الَّذِي ذَهَبُوا بِهِ مِنْكَ قَالَ لاَ حَدَّثَنِي أَبِي أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَدِّ الأَمَانَةَ إِلَى مَنِ ائْتَمَنَكَ وَلاَ تَخُنْ مَنْ خَانَكَ ‏"‏ ‏.‏\hadithno{3534}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Yusuf ibn Malik al-Makki: I used to write (the account of) the expenditure incurred on orphans who were under the guardianship of so-and-so. They cheated him by one thousand dirhams and he paid these (this amount) to them. I then got double the property which they deserved. I said (to the man: Take one thousand (dirhams) which they have taken from you (by cheating). He said: No, my father has told me that he heard the Messenger of Allah (ﷺ) say: Pay the deposit to him who deposited it with you, and do not betray him who betrays you}}
\hadithdefcmd{abudawud}{3535}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَأَحْمَدُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، عَنْ شَرِيكٍ، - قَالَ ابْنُ الْعَلاَءِ وَقَيْسٍ - عَنْ أَبِي حُصَيْنٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَدِّ الأَمَانَةَ إِلَى مَنِ ائْتَمَنَكَ وَلاَ تَخُنْ مَنْ خَانَكَ ‏"‏ ‏.‏\hadithno{3535}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Pay the deposit to him who deposited it with you, and do not betray him who betrayed you}}
\hadithdefcmd{abudawud}{3536}{حَدَّثَنَا عَلِيُّ بْنُ بَحْرٍ، وَعَبْدُ الرَّحِيمِ بْنُ مُطَرِّفٍ الرُّؤَاسِيُّ، قَالاَ حَدَّثَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ بْنِ أَبِي إِسْحَاقَ السَّبِيعِيُّ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْبَلُ الْهَدِيَّةَ وَيُثِيبُ عَلَيْهَا ‏.‏\hadithno{3536}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2585)}\hadithtrans{Narrated 'Aishah:That the Prophet (ﷺ) used to accept a gift and make return for it}}
\hadithdefcmd{abudawud}{3537}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ الْفَضْلِ - حَدَّثَنِي مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَايْمُ اللَّهِ لاَ أَقْبَلُ بَعْدَ يَوْمِي هَذَا مِنْ أَحَدٍ هَدِيَّةً إِلاَّ أَنْ يَكُونَ مُهَاجِرًا قُرَشِيًّا أَوْ أَنْصَارِيًّا أَوْ دَوْسِيًّا أَوْ ثَقَفِيًّا ‏"‏ ‏.‏\hadithno{3537}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: I swear by Allah, I shall not accept gift from anyone after this day except from an immigrant Qarashi, an Ansari a Dawsi or a Thaqafi}}
\hadithdefcmd{abudawud}{3538}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، وَهَمَّامٌ، وَشُعْبَةُ، قَالُوا حَدَّثَنَا قَتَادَةُ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْعَائِدِ فِي قَيْئِهِ ‏"‏ ‏.‏ قَالَ هَمَّامٌ وَقَالَ قَتَادَةُ وَلاَ نَعْلَمُ الْقَىْءَ إِلاَّ حَرَامًا ‏.‏\hadithno{3538}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2621) Sahih Muslim (1622)}\hadithtrans{Narrated Ibn 'Abbas: The Prophet (ﷺ) as saying: One who seeks to take back a gift like the one who returns to it vomit. Hammam said: "And Qatadah said: We regard vomiting as unlawful}}
\hadithdefcmd{abudawud}{3539}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، وَابْنِ، عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِرَجُلٍ أَنْ يُعْطِيَ عَطِيَّةً أَوْ يَهَبَ هِبَةً فَيَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فِيمَا يُعْطِي وَلَدَهُ وَمَثَلُ الَّذِي يُعْطِي الْعَطِيَّةَ ثُمَّ يَرْجِعُ فِيهَا كَمَثَلِ الْكَلْبِ يَأْكُلُ فَإِذَا شَبِعَ قَاءَ ثُمَّ عَادَ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{3539}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah Ibn Umar ; Abdullah Ibn Abbas: The Prophet (ﷺ) said: It is not lawful for a man to make a donation or give a gift and then take it back, except a father regarding what he gives his child. One who gives a gift and then takes it back is like a dog which eats and vomits when it is full, then returns to its vomit}}
\hadithdefcmd{abudawud}{3540}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، أَنَّ عَمْرَو بْنَ شُعَيْبٍ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الَّذِي يَسْتَرِدُّ مَا وَهَبَ كَمَثَلِ الْكَلْبِ يَقِيءُ فَيَأْكُلُ قَيْئَهُ فَإِذَا اسْتَرَدَّ الْوَاهِبُ فَلْيُوَقَّفْ فَلْيُعَرَّفْ بِمَا اسْتَرَدَّ ثُمَّ لِيُدْفَعْ إِلَيْهِ مَا وَهَبَ ‏"‏ ‏.‏\hadithno{3540}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: The similitude of the one who takes back what he gifted is like that of a dog which vomits and then it eats vomit. When a donor seeks to take back (his gift), it should be made known and he informed why he sought to take it back. Then whatever he donated should be returned to him}}
\hadithdefcmd{abudawud}{3541}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عُمَرَ بْنِ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَفَعَ لأَخِيهِ بِشَفَاعَةٍ فَأَهْدَى لَهُ هَدِيَّةً عَلَيْهَا فَقَبِلَهَا فَقَدْ أَتَى بَابًا عَظِيمًا مِنْ أَبْوَابِ الرِّبَا ‏"‏ ‏.‏\hadithno{3541}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUmamah: The Prophet (ﷺ) said: If anyone intercedes for his brother and he presents a gift to him for it and he accepts it, he approaches a great door of the doors of usury}}
\hadithdefcmd{abudawud}{3542}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، وَأَخْبَرَنَا مُغِيرَةُ، وَأَخْبَرَنَا دَاوُدُ، عَنِ الشَّعْبِيِّ، وَأَنْبَأَنَا مُجَالِدٌ، وَإِسْمَاعِيلُ بْنُ سَالِمٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ أَنْحَلَنِي أَبِي نُحْلاً - قَالَ إِسْمَاعِيلُ بْنُ سَالِمٍ مِنْ بَيْنِ الْقَوْمِ نِحْلَةً غُلاَمًا لَهُ - قَالَ فَقَالَتْ لَهُ أُمِّي عَمْرَةُ بِنْتُ رَوَاحَةَ إِيتِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَشْهِدْهُ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَشْهَدَهُ فَذَكَرَ ذَلِكَ لَهُ فَقَالَ إِنِّي نَحَلْتُ ابْنِي النُّعْمَانَ نُحْلاً وَإِنَّ عَمْرَةَ سَأَلَتْنِي أَنْ أُشْهِدَكَ عَلَى ذَلِكَ قَالَ فَقَالَ ‏"‏ أَلَكَ وَلَدٌ سِوَاهُ ‏"‏ ‏.‏ قَالَ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَكُلَّهُمْ أَعْطَيْتَ مِثْلَ مَا أَعْطَيْتَ النُّعْمَانَ ‏"‏ ‏.‏ قَالَ لاَ قَالَ فَقَالَ بَعْضُ هَؤُلاَءِ الْمُحَدِّثِينَ ‏"‏ هَذَا جَوْرٌ ‏"‏ ‏.‏ وَقَالَ بَعْضُهُمْ ‏"‏ هَذَا تَلْجِئَةٌ فَأَشْهِدْ عَلَى هَذَا غَيْرِي ‏"‏ ‏.‏ قَالَ مُغِيرَةُ فِي حَدِيثِهِ ‏"‏ أَلَيْسَ يَسُرُّكَ أَنْ يَكُونُوا لَكَ فِي الْبِرِّ وَاللُّطْفِ سَوَاءً ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَشْهِدْ عَلَى هَذَا غَيْرِي ‏"‏ ‏.‏ وَذَكَرَ مُجَالِدٌ فِي حَدِيثِهِ ‏"‏ إِنَّ لَهُمْ عَلَيْكَ مِنَ الْحَقِّ أَنْ تَعْدِلَ بَيْنَهُمْ كَمَا أَنَّ لَكَ عَلَيْهِمْ مِنَ الْحَقِّ أَنْ يَبَرُّوكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ فِي حَدِيثِ الزُّهْرِيِّ قَالَ بَعْضُهُمْ ‏"‏ أَكُلَّ بَنِيكَ ‏"‏ ‏.‏ وَقَالَ بَعْضُهُمْ ‏"‏ وَلَدِكَ ‏"‏ ‏.‏ وَقَالَ ابْنُ أَبِي خَالِدٍ عَنِ الشَّعْبِيِّ فِيهِ ‏"‏ أَلَكَ بَنُونَ سِوَاهُ ‏"‏ ‏.‏ وَقَالَ أَبُو الضُّحَى عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ‏"‏ أَلَكَ وَلَدٌ غَيْرُهُ ‏"‏ ‏.‏\hadithno{3542}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Nu'man b. Bashir: My father gave me a gift. The narrator Isma'il b. Salim said: (He gave me) his slave as a gift. My mother 'Umrah daughter of Rawahah said: Go to the Messenger of Allah and call him as witness. He then came to the Prophet (ﷺ) and mentioned it to him. He said him: I have given my son al-Nu'man a gift, and 'Umrah has asked me to call you as witness to it. He asked him: Have you children other than him? He said: I replied: Yes. He again asked: Have you given the rest of them the same as you have given al-Nu'man ? He said: No. Some of these narrators said in their version (that the Prophet said:) This in injustice. The others said in their version (that the Prophet said:) This is under force. So call some other person than me as witness to it. Mughirah said in his version: (The Prophet asked): Are you not pleased with the fact that all of them may be equal in virtue and grace ? He replied: Yes. He said: Then call some other person than me as witness to it. Mujahid mentioned in his version: They have right to you that you should do justice to them, as you have right to them that they should do good to you. Abu Dawud said: In the version of al-Zuhri some (narrators) said: (Have you given) to all your sons ? and some (narrators) said: Your children. Ibn Abi Khalid narrated from al-Sha'bi in his version: Have your sons other than him ? Abu al-Duha narrated on the authority of al-Nu'man b. Bashir: Have you children other than him ?}}
\hadithdefcmd{abudawud}{3543}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، حَدَّثَنِي النُّعْمَانُ بْنُ بَشِيرٍ، قَالَ أَعْطَاهُ أَبُوهُ غُلاَمًا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذَا الْغُلاَمُ ‏"‏ ‏.‏ قَالَ غُلاَمِي أَعْطَانِيهِ أَبِي ‏.‏ قَالَ ‏"‏ فَكُلَّ إِخْوَتِكَ أَعْطَى كَمَا أَعْطَاكَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏\hadithno{3543}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1623)}\hadithtrans{Narrated Al-Nu'man b. Bashir:That his father had given him a slave. The Messenger of Allah (ﷺ) said: What is this slave ? He replied: This is my slave which my father has given me. He asked: Has he given all your brothers the same as he has given you? He replied: No. He then said: Return it, then}}
\hadithdefcmd{abudawud}{3544}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ حَاجِبِ بْنِ الْمُفَضَّلِ بْنِ الْمُهَلَّبِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اعْدِلُوا بَيْنَ أَوْلاَدِكُمْ اعْدِلُوا بَيْنَ أَبْنَائِكُمْ ‏"‏ ‏.‏\hadithno{3544}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated An-Nu'man ibn Bashir: The Prophet (ﷺ) said: Act equally between your children; Act equally between your sons}}
\hadithdefcmd{abudawud}{3545}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَتِ امْرَأَةُ بَشِيرٍ انْحَلِ ابْنِي غُلاَمَكَ وَأَشْهِدْ لِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ ابْنَةَ فُلاَنٍ سَأَلَتْنِي أَنْ أَنْحَلَ ابْنَهَا غُلاَمًا وَقَالَتْ لِي أَشْهِدْ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏"‏ لَهُ إِخْوَةٌ ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَكُلَّهُمْ أَعْطَيْتَ مِثْلَ مَا أَعْطَيْتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلَيْسَ يَصْلُحُ هَذَا وَإِنِّي لاَ أَشْهَدُ إِلاَّ عَلَى حَقٍّ ‏"‏ ‏.‏\hadithno{3545}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1624)}\hadithtrans{Narrated Jabir:Bashir's wife said (to her husband): Give my son your slave, and call the Messenger of Allah (ﷺ) as witness for me. So he came to the Messenger of Allah (ﷺ) and said: The daughter of so-and-so has asked me to give her som my slave and said to me: Call the Messenger of Allah (ﷺ) as witness for her. He asked: Has he brothers? He replied: Yes. He again asked: Has he given them all the same as you have given him? He replied: No. He said: This is not good, and I will be a witness to what it right}}
\hadithdefcmd{abudawud}{3546}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، وَحَبِيبٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجُوزُ لاِمْرَأَةٍ أَمْرٌ فِي مَالِهَا إِذَا مَلَكَ زَوْجُهَا عِصْمَتَهَا ‏"‏ ‏.‏\hadithno{3546}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib:On his father's authority, said that his grandfather reported the Messenger of Allah (ﷺ) as saying: It is not permissible for a woman to present a gift from the property which she has in her possession when her husband owns her chastity}}
\hadithdefcmd{abudawud}{3547}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا حُسَيْنٌ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ أَبَاهُ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجُوزُ لاِمْرَأَةٍ عَطِيَّةٌ إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏\hadithno{3547}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: It is not permissible for a woman to present a gift (from her husband's property) except with the permission of her husband}}
\hadithdefcmd{abudawud}{3548}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3548}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2626) Sahih Muslim (1626)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: Life tenancy is permissible}}
\hadithdefcmd{abudawud}{3549}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3549}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{A similar tradition has also been transmitted by Samurah from the Prophet (ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{3550}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ الْعُمْرَى لِمَنْ وُهِبَتْ لَهُ ‏"‏ ‏.‏\hadithno{3550}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2625) Sahih Muslim (1625)}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) has saying: What is given in life-tenancy belongs to the one to whom it was given}}
\hadithdefcmd{abudawud}{3551}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، أَخْبَرَنِي الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أُعْمِرَ عُمْرَى فَهِيَ لَهُ وَلِعَقِبِهِ يَرِثُهَا مَنْ يَرِثُهُ مِنْ عَقِبِهِ ‏"‏ ‏.‏\hadithno{3551}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If anyone is given life-tenancy, it belongs to him and to his descendants. His descendants who inherit him will inherit from it}}
\hadithdefcmd{abudawud}{3552}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي الْحَوَارِيِّ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، وَعُرْوَةَ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَكَذَا رَوَاهُ اللَّيْثُ بْنُ سَعْدٍ عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ جَابِرٍ ‏.‏\hadithno{3552}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been narrated by Jabir from the Prophet (ﷺ) to the same effect through a different chain of narrators. Abu Dawud said:A similar tradition has also been transmitted by al-Laith b. Sa'd from al-Zuhri, from Abu Salamah from Jabir}}
\hadithdefcmd{abudawud}{3553}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكٌ، - يَعْنِي ابْنَ أَنَسٍ - عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَإِنَّهَا لِلَّذِي يُعْطَاهَا لاَ تَرْجِعُ إِلَى الَّذِي أَعْطَاهَا لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏"‏ ‏.‏\hadithno{3553}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1625)}\hadithtrans{Narrated Jabir:The Messenger of Allah (ﷺ) as saying: If anyone has property given him in life-tenancy for the use of himself and his descendants, it belongs to the one to whom it is given and does not return to the one who gave it, because he gave a gift which may be inherited}}
\hadithdefcmd{abudawud}{3554}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ عُقَيْلٌ عَنِ ابْنِ شِهَابٍ، وَيَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنِ ابْنِ شِهَابٍ، وَاخْتُلِفَ، عَلَى الأَوْزَاعِيِّ فِي لَفْظِهِ عَنِ ابْنِ شِهَابٍ، وَرَوَاهُ، فُلَيْحُ بْنُ سُلَيْمَانَ مِثْلَ حَدِيثِ مَالِكٍ ‏.‏\hadithno{3554}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn Shihab (Al-Zuhri) through a different chain of narrators and to the same effect. Abu Dawud said:A similar tradition has been transmitted by 'Aqil from Ibn Shihab and by Yazid b. Abi Habib from Shihab. Al-Auza'i's wordings vary from those of Ibn Shihab. Fulaih b. Sulaiman also narrated the tradition like that of Malik}}
\hadithdefcmd{abudawud}{3555}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ إِنَّمَا الْعُمْرَى الَّتِي أَجَازَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَقُولَ هِيَ لَكَ وَلِعَقِبِكَ ‏.‏ فَأَمَّا إِذَا قَالَ هِيَ لَكَ مَا عِشْتَ ‏.‏ فَإِنَّهَا تَرْجِعُ إِلَى صَاحِبِهَا ‏.‏\hadithno{3555}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1625)}\hadithtrans{Narrated Jabir bin ‘Abdullah :The life-tenancy which the Messenger of Allah (ﷺ) allowed was only that one should say: It is for you and your descendants. When he says: It is yours as long as you live, it returns to its owner}}
\hadithdefcmd{abudawud}{3556}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُرْقِبُوا وَلاَ تُعْمِرُوا فَمَنْ أُرْقِبَ شَيْئًا أَوْ أُعُمِرَهُ فَهُوَ لِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{3556}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1625)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: Do not give property to go to the survivor and do not give life-tenancy. If anyone is given something to the survivor or given life-tenancy, it goes to his heirs}}
\hadithdefcmd{abudawud}{3557}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبٍ، - يَعْنِي ابْنَ أَبِي ثَابِتٍ - عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ طَارِقٍ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي امْرَأَةٍ مِنَ الأَنْصَارِ أَعْطَاهَا ابْنُهَا حَدِيقَةً مِنْ نَخْلٍ فَمَاتَتْ فَقَالَ ابْنُهَا إِنَّمَا أَعْطَيْتُهَا حَيَاتَهَا ‏.‏ وَلَهُ إِخْوَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هِيَ لَهَا حَيَاتَهَا وَمَوْتَهَا ‏"‏ ‏.‏ قَالَ كُنْتُ تَصَدَّقْتُ بِهَا عَلَيْهَا ‏.‏ قَالَ ‏"‏ ذَلِكَ أَبْعَدُ لَكَ ‏"‏ ‏.‏\hadithno{3557}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) decided a case of a woman from the Ansar to whom an orchard of date-palms was given by her son. She then died. Her son said: I gave it to her for her life, and she has brothers. Thereupon the Messenger of Allah (ﷺ) said: It belongs to her during her life and after death. He then said: I gave a sadaqah (charity to her. He replied: It is more unexpected from you)}}
\hadithdefcmd{abudawud}{3558}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا دَاوُدُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى جَائِزَةٌ لأَهْلِهَا وَالرُّقْبَى جَائِزَةٌ لأَهْلِهَا ‏"‏ ‏.‏\hadithno{3558}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: Life-tenancy is lawful for the one to whom it is given and donation of property to go to the survivor is lawful to whom it is given}}
\hadithdefcmd{abudawud}{3559}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، قَالَ قَرَأْتُ عَلَى مَعْقِلٍ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنْ حُجْرٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْمَرَ شَيْئًا فَهُوَ لِمُعْمَرِهِ مَحْيَاهُ وَمَمَاتَهُ وَلاَ تُرْقِبُوا فَمَنْ أَرْقَبَ شَيئًا فَهُوَ سَبِيلُهُ ‏"‏ ‏.‏\hadithno{3559}\hadithgrade{Al-Albani: Hasan Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zayd ibn Thabit: The Prophet (ﷺ) said: If anyone gives something in life-tenancy, it belongs to the one to whom it is given, in his life and after his death; and do not give property to go to the survivor, for if anyone gives something to to to the survivor, it belongs to him}}
\hadithdefcmd{abudawud}{3560}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، عَنْ عُبَيْدِ اللَّهِ بْنِ مُوسَى، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، عَنْ مُجَاهِدٍ، قَالَ الْعُمْرَى أَنْ يَقُولَ الرَّجُلُ لِلرَّجُلِ هُوَ لَكَ مَا عِشْتَ فَإِذَا قَالَ ذَلِكَ فَهُوَ لَهُ وَلِوَرَثَتِهِ وَالرُّقْبَى هُوَ أَنْ يَقُولَ الإِنْسَانُ هُوَ لِلآخِرِ مِنِّي وَمِنْكَ ‏.‏\hadithno{3560}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Mujahid said:'Umra' means that a man says to another man: It belongs to you so long as you live. When he says that, it belongs to him and to his heirs. Ruqba means that a man says to another: From me and from you}}
\hadithdefcmd{abudawud}{3561}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، ع��نْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَى الْيَدِ مَا أَخَذَتْ حَتَّى تُؤَدِّيَ ‏"‏ ‏.‏ ثُمَّ إِنَّ الْحَسَنَ نَسِيَ فَقَالَ هُوَ أَمِينُكَ لاَ ضَمَانَ عَلَيْهِ ‏.‏\hadithno{3561}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah:The Prophet (ﷺ) as saying: The hand which takes is responsible till it pays. Then al-Hasan forgot and said: (If you give something on loan to a man), he is your depositor ; there is no compensation (for it) on him}}
\hadithdefcmd{abudawud}{3562}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، وَسَلَمَةُ بْنُ شَبِيبٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا شَرِيكٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ أُمَيَّةَ بْنِ صَفْوَانَ بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعَارَ مِنْهُ أَدْرَاعًا يَوْمَ حُنَيْنٍ فَقَالَ أَغَصْبٌ يَا مُحَمَّدُ فَقَالَ ‏ "‏ لاَ بَلْ عَارِيَةٌ مَضْمُونَةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذِهِ رِوَايَةُ يَزِيدَ بِبَغْدَادَ وَفِي رِوَايَتِهِ بِوَاسِطَ تَغَيُّرٌ عَلَى غَيْرِ هَذَا ‏.‏\hadithno{3562}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Safwan ibn Umayyah: The Messenger of Allah (ﷺ) borrowed coats of mail from him on the day of (the battle of) Hunayn. He asked: Are you taking them by force. Muhammad? He replied: No, it is a loan with a guarantee of their return. Abu Dawud said: This tradition narrated by Yazid (b. Harun) at Baghdad. There is some change in the tradition narrated by him at Wasit, which is something different}}
\hadithdefcmd{abudawud}{3563}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ أُنَاسٍ، مِنْ آلِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَا صَفْوَانُ هَلْ عِنْدَكَ مِنْ سِلاَحٍ ‏"‏ ‏.‏ قَالَ عَارِيَةً أَمْ غَصْبًا قَالَ ‏"‏ لاَ بَلْ عَارِيَةً ‏"‏ ‏.‏ فَأَعَارَهُ مَا بَيْنَ الثَّلاَثِينَ إِلَى الأَرْبَعِينَ دِرْعًا وَغَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم حُنَيْنًا فَلَمَّا هُزِمَ الْمُشْرِكُونَ جُمِعَتْ دُرُوعُ صَفْوَانَ فَفَقَدَ مِنْهَا أَدْرَاعًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِصَفْوَانَ ‏"‏ إِنَّا قَدْ فَقَدْنَا مِنْ أَدْرَاعِكَ أَدْرَاعًا فَهَلْ نَغْرَمُ لَكَ ‏"‏ ‏.‏ قَالَ لاَ يَا رَسُولَ اللَّهِ لأَنَّ فِي قَلْبِي الْيَوْمَ مَا لَمْ يَكُنْ يَوْمَئِذٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَانَ أَعَارَهُ قَبْلَ أَنْ يُسْلِمَ ثُمَّ أَسْلَمَ ‏.‏\hadithno{3563}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Some people: AbdulAziz ibn Rufay' narrated on the authority of some people from the descendants of Abdullah ibn Safwan who reported the Messenger of Allah (ﷺ) as saying: Have you weapons, Safwan? He asked: On loan or by force? He replied: No, but on loan. So he lent him coats of mail numbering between thirty and forty! The Messenger of Allah (ﷺ) fought the battle of Hunayn. When the polytheists were defeated, the coats of mail of Safwan were collected. Some of them were lost. The Messenger of Allah (ﷺ) said to Safwan: We have lost some coats of mail from your coats of mail. Should we pay compensation to you? He replied: No. Messenger of Allah, for I have in my heart today what I did not have that day. Abu Dawud said: He lent him before embracing Islam. Then he embraced Islam}}
\hadithdefcmd{abudawud}{3564}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، عَنْ عَطَاءٍ، عَنْ نَاسٍ، مِنْ آلِ صَفْوَانَ قَالَ اسْتَعَارَ النَّبِيُّ صلى الله عليه وسلم فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{3564}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by 'Ata from some people of the descendants of Safwan saying:The Prophet (ﷺ) borrowed. He then transmitted the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{3565}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ الْحَوْطِيُّ، حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ شُرَحْبِيلَ بْنِ مُسْلِمٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ فَلاَ وَصِيَّةَ لِوَارِثٍ وَلاَ تُنْفِقُ الْمَرْأَةُ شَيْئًا مِنْ بَيْتِهَا إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ وَلاَ الطَّعَامَ قَالَ ‏"‏ ذَاكَ أَفْضَلُ أَمْوَالِنَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ الْعَارِيَةُ مُؤَدَّاةٌ وَالْمِنْحَةُ مَرْدُودَةٌ وَالدَّيْنُ مَقْضِيٌّ وَالزَّعِيمُ غَارِمٌ ‏"‏ ‏.‏\hadithno{3565}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuUmamah: I heard the Messenger of Allah (ﷺ) Said: Allah , Most Exalted, has appointed for everyone who has a right what is due to him, and no will be made to an heir, and a woman should not spend anything from her house except with the permission of her husband. He was asked: Even foodgrain, Messenger of Allah? He replied: That is the best of our property. He then said: A loan must be paid back, a she-camel lent for a time for milking must be returned, a debt must be discharged, one who stands surety is held responsible}}
\hadithdefcmd{abudawud}{3566}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ الْعُصْفُرِيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَتَتْكَ رُسُلِي فَأَعْطِهِمْ ثَلاَثِينَ دِرْعًا وَثَلاَثِينَ بَعِيرًا ‏"‏ ‏.‏ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ أَعَارِيَةً مَضْمُونَةً أَوْ عَارِيَةً مُؤَدَّاةً قَالَ ‏"‏ بَلْ مُؤَدَّاةً ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ حَبَّانُ خَالُ هِلاَلِ الرَّأْىِ ‏.‏\hadithno{3566}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ya'la ibn Umayyah: The Messenger of Allah (ﷺ) said to me: When my messengers come to you, give them thirty coats of mail, and thirty camels. I asked: Messenger of Allah, is it a loan with a guarantee of its return, or a loan to be paid back? He replied : It is a loan to be paid back}}
\hadithdefcmd{abudawud}{3567}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَ بَعْضِ نِسَائِهِ فَأَرْسَلَتْ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ مَعَ خَادِمِهَا بِقَصْعَةٍ فِيهَا طَعَامٌ قَالَ فَضَرَبَتْ بِيَدِهَا فَكَسَرَتِ الْقَصْعَةَ - قَالَ ابْنُ الْمُثَنَّى - فَأَخَذَ النَّبِيُّ صلى الله عليه وسلم الْكِسْرَتَيْنِ فَضَمَّ إِحْدَاهُمَا إِلَى الأُخْرَى فَجَعَلَ يَجْمَعُ فِيهَا الطَّعَامَ وَيَقُولُ ‏"‏ غَارَتْ أُمُّكُمْ ‏"‏ ‏.‏ زَادَ ابْنُ الْمُثَنَّى ‏"‏ كُلُوا ‏"‏ ‏.‏ فَأَكَلُوا حَتَّى جَاءَتْ قَصْعَتُهَا الَّتِي فِي بَيْتِهَا ثُمَّ رَجَعْنَا إِلَى لَفْظِ حَدِيثِ مُسَدَّدٍ وَقَالَ ‏"‏ كُلُوا ‏"‏ ‏.‏ وَحَبَسَ الرَّسُولَ وَالْقَصْعَةَ حَتَّى فَرَغُوا فَدَفَعَ الْقَصْعَةَ الصَّحِيحَةَ إِلَى الرَّسُولِ وَحَبَسَ الْمَكْسُورَةَ فِي بَيْتِهِ ‏.‏\hadithno{3567}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2481)}\hadithtrans{Anas said: The Messenger of Allah (ﷺ) was with one of his wives. One of the Mothers of faithful sent a bowl containing food through a servant of hers. She struck with her hand and broke the bowl. Ibn al-Muthanna's version has: The Prophet (ﷺ) took the pieces of the bowl, and joined one with the other, and began to collect the food in it, saying: Your mother is jealous. Ibn al-Muthanna added: Eat. They ate till a bowl of the one in whose house he was brought. Abu Dawud said: We then returned to the version of the tradition of Musaddad: He said: Eat. He detained the servant and the bowl till they were free. Then he returned the sound bowl to the messenger and detained the broken one (bowl) in his house}}
\hadithdefcmd{abudawud}{3568}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي فُلَيْتٌ الْعَامِرِيُّ، عَنْ جَسْرَةَ بِنْتِ دِجَاجَةَ، قَالَتْ قَالَتْ عَائِشَةُ رضى الله عنها مَا رَأَيْتُ صَانِعًا طَعَامًا مِثْلَ صَفِيَّةَ صَنَعَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم طَعَامًا فَبَعَثَتْ بِهِ فَأَخَذَنِي أَفْكَلٌ فَكَسَرْتُ الإِنَاءَ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا كَفَّارَةُ مَا صَنَعْتُ قَالَ ‏ "‏ إِنَاءٌ مِثْلُ إِنَاءٍ وَطَعَامٌ مِثْلُ طَعَامٍ ‏"‏ ‏.‏\hadithno{3568}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I saw no one cooking food like Safiyyah. She cooked food for the Messenger of Allah (ﷺ) and sent it. I became angry and broke the vessel. I then asked: Messenger of Allah, what is the atonement for what I have done? He replied: A vessel like (this) vessel and food like (this) food}}
\hadithdefcmd{abudawud}{3569}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حَرَامِ بْنِ مُحَيِّصَةَ، عَنْ أَبِيهِ، أَنَّ نَاقَةً، لِلْبَرَاءِ بْنِ عَازِبٍ دَخَلَتْ حَائِطَ رَجُلٍ فَأَفْسَدَتْهُ عَلَيْهِمْ فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَهْلِ الأَمْوَالِ حِفْظَهَا بِالنَّهَارِ وَعَلَى أَهْلِ الْمَوَاشِي حِفْظَهَا بِاللَّيْلِ ‏.‏\hadithno{3569}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muhayyisah: The she-camel of Bara' ibn Azib entered the garden of a man and did damage to it. The Messenger of Allah (ﷺ) gave decision that the owners of properties are responsible for guarding them by day, and the owners of animals are responsible for guarding them by night}}
\hadithdefcmd{abudawud}{3570}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ حَرَامِ بْنِ مُحَيِّصَةَ الأَنْصَارِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَتْ لَهُ نَاقَةٌ ضَارِيَةٌ فَدَخَلَتْ حَائِطًا فَأَفْسَدَتْ فِيهِ فَكُلِّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا فَقَضَى أَنَّ حِفْظَ الْحَوَائِطِ بِالنَّهَارِ عَلَى أَهْلِهَا وَأَنَّ حِفْظَ الْمَاشِيَةِ بِاللَّيْلِ عَلَى أَهْلِهَا وَأَنَّ عَلَى أَهْلِ الْمَاشِيَةِ مَا أَصَابَتْ مَاشِيَتُهُمْ بِاللَّيْلِ ‏.‏\hadithno{3570}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara' ibn Azib: Al-Bara' had a she-camel which was accustomed to graze the standing crop belonging to the people. She entered a garden and did damage to it. The Messenger of Allah (ﷺ) was informed about it. So he gave decision that the owners of gardens are responsible for guarding them by day, and the owners of the animals are responsible for guarding them by night. Any damage done by animals during the night is a responsibility lying on their owners}}
